# zoom_us

ZoomUs - the Ruby gem for the Zoom API

The Zoom API allows developers to safely and securely access information from Zoom. You can use this API to build private services or public applications on the [Zoom App Marketplace](http://marketplace.zoom.us). To learn how to get your credentials and create private/public applications, read our [Authorization Guide](https://marketplace.zoom.us/docs/guides/authorization/credentials). All endpoints are available via `https` and are located at `api.zoom.us/v2/`.  For instance you can list all users on an account via `https://api.zoom.us/v2/users/`.

This SDK is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: 2.0.0
- Package version: 0.1.1
- Build package: io.swagger.codegen.languages.RubyClientCodegen
For more information, please visit [https://developer.zoom.us/](https://developer.zoom.us/)

## Installation

### Build a gem

To build the Ruby code into a gem:

```shell
gem build zoom_us.gemspec
```

Then either install the gem locally:

```shell
gem install ./zoom_us-0.1.1.gem
```
(for development, run `gem install --dev ./zoom_us-0.1.1.gem` to install the development dependencies)

or publish the gem to a gem hosting service, e.g. [RubyGems](https://rubygems.org/).

Finally add this to the Gemfile:

    gem 'zoom_us', '~> 0.1.1'

### Install from Git

If the Ruby gem is hosted at a git repository: https://github.com/GIT_USER_ID/GIT_REPO_ID, then add the following in the Gemfile:

    gem 'zoom_us', :git => 'https://github.com/GIT_USER_ID/GIT_REPO_ID.git'

### Include the Ruby code directly

Include the Ruby code directly using `-I` as follows:

```shell
ruby -Ilib script.rb
```

## Getting Started

Please follow the [installation](#installation) procedure and then run the following code:
```ruby
# Load the gem
require 'zoom_us'

# Setup authorization
ZoomUs.configure do |config|
  # Configure OAuth2 access token for authorization: OAuth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = ZoomUs::AccountsApi.new

account_id = 'account_id_example' # String | The account ID.


begin
  #Get a Sub Account
  result = api_instance.account(account_id)
  p result
rescue ZoomUs::ApiError => e
  puts "Exception when calling AccountsApi->account: #{e}"
end

```

## Documentation for API Endpoints

All URIs are relative to *https://api.zoom.us/v2*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*ZoomUs::AccountsApi* | [**account**](docs/AccountsApi.md#account) | **GET** /accounts/{accountId} | Get a Sub Account
*ZoomUs::AccountsApi* | [**account_create**](docs/AccountsApi.md#account_create) | **POST** /accounts | Create a Sub Account
*ZoomUs::AccountsApi* | [**account_disassociate**](docs/AccountsApi.md#account_disassociate) | **DELETE** /accounts/{accountId} | Disassociate a Sub Account
*ZoomUs::AccountsApi* | [**account_managed_domain**](docs/AccountsApi.md#account_managed_domain) | **GET** /accounts/{accountId}/managed_domains | Get Managed Domains
*ZoomUs::AccountsApi* | [**account_options_update**](docs/AccountsApi.md#account_options_update) | **PATCH** /accounts/{accountId}/options | Update Options
*ZoomUs::AccountsApi* | [**account_settings**](docs/AccountsApi.md#account_settings) | **GET** /accounts/{accountId}/settings | Get Settings
*ZoomUs::AccountsApi* | [**account_settings_update**](docs/AccountsApi.md#account_settings_update) | **PATCH** /accounts/{accountId}/settings | Update Settings
*ZoomUs::AccountsApi* | [**account_trusted_domain**](docs/AccountsApi.md#account_trusted_domain) | **GET** /accounts/{accountId}/trusted_domains | Get Trusted Domains
*ZoomUs::AccountsApi* | [**accounts**](docs/AccountsApi.md#accounts) | **GET** /accounts | List Sub Accounts
*ZoomUs::AccountsApi* | [**get_account_lock_settings**](docs/AccountsApi.md#get_account_lock_settings) | **GET** /accounts/{accountId}/lock_settings | Get Locked Settings
*ZoomUs::AccountsApi* | [**update_account_lock_settings**](docs/AccountsApi.md#update_account_lock_settings) | **PATCH** /accounts/{accountId}/lock_settings | Update Locked Settings
*ZoomUs::AccountsApi* | [**update_account_owner**](docs/AccountsApi.md#update_account_owner) | **PUT** /accounts/{accountId}/owner | Update the Account Owner
*ZoomUs::BillingApi* | [**account_billing**](docs/BillingApi.md#account_billing) | **GET** /accounts/{accountId}/billing | Get Billing Information
*ZoomUs::BillingApi* | [**account_billing_update**](docs/BillingApi.md#account_billing_update) | **PATCH** /accounts/{accountId}/billing | Update Billing Information
*ZoomUs::BillingApi* | [**account_plan_addon_cancel**](docs/BillingApi.md#account_plan_addon_cancel) | **PATCH** /accounts/{accountId}/plans/addons/status | Cancel  Additional Plans
*ZoomUs::BillingApi* | [**account_plan_addon_create**](docs/BillingApi.md#account_plan_addon_create) | **POST** /accounts/{accountId}/plans/addons | Add an Additional Plan
*ZoomUs::BillingApi* | [**account_plan_addon_update**](docs/BillingApi.md#account_plan_addon_update) | **PUT** /accounts/{accountId}/plans/addons | Update an Additional Plan
*ZoomUs::BillingApi* | [**account_plan_base_delete**](docs/BillingApi.md#account_plan_base_delete) | **PATCH** /accounts/{accountId}/plans/base/status | Cancel Base Plan
*ZoomUs::BillingApi* | [**account_plan_base_update**](docs/BillingApi.md#account_plan_base_update) | **PUT** /accounts/{accountId}/plans/base | Update a Base Plan
*ZoomUs::BillingApi* | [**account_plan_create**](docs/BillingApi.md#account_plan_create) | **POST** /accounts/{accountId}/plans | Subscribe to Plans
*ZoomUs::BillingApi* | [**account_plans**](docs/BillingApi.md#account_plans) | **GET** /accounts/{accountId}/plans | Get Plan Information
*ZoomUs::BillingApi* | [**get_plan_usage**](docs/BillingApi.md#get_plan_usage) | **GET** /accounts/{accountId}/plans/usage | Get Plan Usage
*ZoomUs::ChatChannelsApi* | [**create_channel**](docs/ChatChannelsApi.md#create_channel) | **POST** /chat/users/me/channels | Create a Channel
*ZoomUs::ChatChannelsApi* | [**delete_channel**](docs/ChatChannelsApi.md#delete_channel) | **DELETE** /chat/channels/{channelId} | Delete a Channel
*ZoomUs::ChatChannelsApi* | [**get_channel**](docs/ChatChannelsApi.md#get_channel) | **GET** /chat/channels/{channelId} | Get a Channel
*ZoomUs::ChatChannelsApi* | [**get_channels**](docs/ChatChannelsApi.md#get_channels) | **GET** /chat/users/me/channels | List User's Channels
*ZoomUs::ChatChannelsApi* | [**invite_channel_members**](docs/ChatChannelsApi.md#invite_channel_members) | **POST** /chat/channels/{channelId}/members | Invite Channel Members
*ZoomUs::ChatChannelsApi* | [**join_channel**](docs/ChatChannelsApi.md#join_channel) | **POST** /chat/channels/{channelId}/members/me | Join a Channel
*ZoomUs::ChatChannelsApi* | [**leave_channel**](docs/ChatChannelsApi.md#leave_channel) | **DELETE** /chat/channels/{channelId}/members/me | Leave a Channel
*ZoomUs::ChatChannelsApi* | [**list_channel_members**](docs/ChatChannelsApi.md#list_channel_members) | **GET** /chat/channels/{channelId}/members | List Channel Members
*ZoomUs::ChatChannelsApi* | [**remove_a_channel_member**](docs/ChatChannelsApi.md#remove_a_channel_member) | **DELETE** /chat/channels/{channelId}/members/{memberId} | Remove a Member
*ZoomUs::ChatChannelsApi* | [**update_channel**](docs/ChatChannelsApi.md#update_channel) | **PATCH** /chat/channels/{channelId} | Update a Channel
*ZoomUs::ChatMessagesApi* | [**delete_chat_message**](docs/ChatMessagesApi.md#delete_chat_message) | **DELETE** /chat/users/me/messages/{messageId} | Delete a Message
*ZoomUs::ChatMessagesApi* | [**edit_message**](docs/ChatMessagesApi.md#edit_message) | **PUT** /chat/users/me/messages/{messageId} | Update a Message
*ZoomUs::ChatMessagesApi* | [**get_chat_messages**](docs/ChatMessagesApi.md#get_chat_messages) | **GET** /chat/users/{userId}/messages | List User's Chat Messages
*ZoomUs::ChatMessagesApi* | [**senda_chat_message**](docs/ChatMessagesApi.md#senda_chat_message) | **POST** /chat/users/me/messages | Send a Chat Message
*ZoomUs::ChatbotMessagesApi* | [**delete_a_chatbot_message**](docs/ChatbotMessagesApi.md#delete_a_chatbot_message) | **DELETE** /im/chat/messages/{message_id} | Delete a Chatbot Message
*ZoomUs::ChatbotMessagesApi* | [**edit_chatbot_message**](docs/ChatbotMessagesApi.md#edit_chatbot_message) | **PUT** /im/chat/messages/{message_id} | Edit a Chatbot Message
*ZoomUs::ChatbotMessagesApi* | [**sendchatbot**](docs/ChatbotMessagesApi.md#sendchatbot) | **POST** /im/chat/messages | Send Chatbot Messages
*ZoomUs::CloudRecordingApi* | [**get_account_cloud_recording**](docs/CloudRecordingApi.md#get_account_cloud_recording) | **GET** /accounts/{accountId}/recordings | List Recordings of an Account
*ZoomUs::CloudRecordingApi* | [**meeting_recording_registrant_create**](docs/CloudRecordingApi.md#meeting_recording_registrant_create) | **POST** /meetings/{meetingId}/recordings/registrants | Create a Recording Registrant
*ZoomUs::CloudRecordingApi* | [**meeting_recording_registrant_status**](docs/CloudRecordingApi.md#meeting_recording_registrant_status) | **PUT** /meetings/{meetingId}/recordings/registrants/status | Update Recording Registrant's Status
*ZoomUs::CloudRecordingApi* | [**meeting_recording_registrants**](docs/CloudRecordingApi.md#meeting_recording_registrants) | **GET** /meetings/{meetingId}/recordings/registrants | List Recording Registrants
*ZoomUs::CloudRecordingApi* | [**recording_delete**](docs/CloudRecordingApi.md#recording_delete) | **DELETE** /meetings/{meetingId}/recordings | Delete Meeting Recordings
*ZoomUs::CloudRecordingApi* | [**recording_delete_one**](docs/CloudRecordingApi.md#recording_delete_one) | **DELETE** /meetings/{meetingId}/recordings/{recordingId} | Delete a Meeting Recording File
*ZoomUs::CloudRecordingApi* | [**recording_get**](docs/CloudRecordingApi.md#recording_get) | **GET** /meetings/{meetingId}/recordings | Get Meeting Recordings
*ZoomUs::CloudRecordingApi* | [**recording_registrant_question_update**](docs/CloudRecordingApi.md#recording_registrant_question_update) | **PATCH** /meetings/{meetingId}/recordings/registrants/questions | Update Registration Questions
*ZoomUs::CloudRecordingApi* | [**recording_registrants_questions_get**](docs/CloudRecordingApi.md#recording_registrants_questions_get) | **GET** /meetings/{meetingId}/recordings/registrants/questions | Get Registration Questions
*ZoomUs::CloudRecordingApi* | [**recording_setting_update**](docs/CloudRecordingApi.md#recording_setting_update) | **GET** /meetings/{meetingId}/recordings/settings | Get Meeting Recording Settings
*ZoomUs::CloudRecordingApi* | [**recording_settings_update**](docs/CloudRecordingApi.md#recording_settings_update) | **PATCH** /meetings/{meetingId}/recordings/settings | Update Meeting Recording Settings
*ZoomUs::CloudRecordingApi* | [**recording_status_update**](docs/CloudRecordingApi.md#recording_status_update) | **PUT** /meetings/{meetingId}/recordings/status | Recover Meeting Recordings
*ZoomUs::CloudRecordingApi* | [**recording_status_update_one**](docs/CloudRecordingApi.md#recording_status_update_one) | **PUT** /meetings/{meetingId}/recordings/{recordingId}/status | Recover a Single Recording
*ZoomUs::CloudRecordingApi* | [**recordings_list**](docs/CloudRecordingApi.md#recordings_list) | **GET** /users/{userId}/recordings | List All Recordings
*ZoomUs::CommonAreaPhonesApi* | [**add_common_area_phone**](docs/CommonAreaPhonesApi.md#add_common_area_phone) | **POST** /phone/common_area_phones | Add a Common Area Phone
*ZoomUs::CommonAreaPhonesApi* | [**delete_common_area_phone**](docs/CommonAreaPhonesApi.md#delete_common_area_phone) | **DELETE** /phone/common_area_phone/{commonAreaPhoneId} | Delete a Common Area Phone
*ZoomUs::CommonAreaPhonesApi* | [**get_a_common_area_phone**](docs/CommonAreaPhonesApi.md#get_a_common_area_phone) | **GET** /phone/common_area_phone/{commonAreaPhoneId} | Get Common Area Phone Details
*ZoomUs::CommonAreaPhonesApi* | [**list_common_area_phones**](docs/CommonAreaPhonesApi.md#list_common_area_phones) | **GET** /phone/common_area_phones | List Common Area Phones
*ZoomUs::CommonAreaPhonesApi* | [**update_common_area_phone**](docs/CommonAreaPhonesApi.md#update_common_area_phone) | **PATCH** /phone/common_area_phone/{commonAreaPhoneId} | Update Common Area Phone
*ZoomUs::ContactsApi* | [**get_user_contact**](docs/ContactsApi.md#get_user_contact) | **GET** /chat/users/me/contacts/{contactId} | Get User's Contact Details
*ZoomUs::ContactsApi* | [**get_user_contacts**](docs/ContactsApi.md#get_user_contacts) | **GET** /chat/users/me/contacts | List User's Contacts
*ZoomUs::ContactsApi* | [**search_company_contacts**](docs/ContactsApi.md#search_company_contacts) | **GET** /contacts | Search Company Contacts
*ZoomUs::DashboardsApi* | [**dashboard_client_feedback**](docs/DashboardsApi.md#dashboard_client_feedback) | **GET** /metrics/client/feedback | List Zoom Meetings Client Feedbacks
*ZoomUs::DashboardsApi* | [**dashboard_client_feedback_detail**](docs/DashboardsApi.md#dashboard_client_feedback_detail) | **GET** /metrics/client/feedback/{feedbackId} | Get Zoom Meetings Client Feedback
*ZoomUs::DashboardsApi* | [**dashboard_crc**](docs/DashboardsApi.md#dashboard_crc) | **GET** /metrics/crc | Get CRC Port Usage
*ZoomUs::DashboardsApi* | [**dashboard_im**](docs/DashboardsApi.md#dashboard_im) | **GET** /metrics/im | Get IM Metrics
*ZoomUs::DashboardsApi* | [**dashboard_issue_detail_zoom_room**](docs/DashboardsApi.md#dashboard_issue_detail_zoom_room) | **GET** /metrics/issues/zoomrooms/{zoomroomId} | Get Issues of Zoom Rooms
*ZoomUs::DashboardsApi* | [**dashboard_issue_zoom_room**](docs/DashboardsApi.md#dashboard_issue_zoom_room) | **GET** /metrics/issues/zoomrooms | Get Top 25 Zoom Rooms with Issues
*ZoomUs::DashboardsApi* | [**dashboard_meeting_detail**](docs/DashboardsApi.md#dashboard_meeting_detail) | **GET** /metrics/meetings/{meetingId} | Get Meeting Details
*ZoomUs::DashboardsApi* | [**dashboard_meeting_participant_qos**](docs/DashboardsApi.md#dashboard_meeting_participant_qos) | **GET** /metrics/meetings/{meetingId}/participants/{participantId}/qos | Get Meeting Participant QOS
*ZoomUs::DashboardsApi* | [**dashboard_meeting_participant_share**](docs/DashboardsApi.md#dashboard_meeting_participant_share) | **GET** /metrics/meetings/{meetingId}/participants/sharing | Get Sharing/Recording Details of Meeting Participants
*ZoomUs::DashboardsApi* | [**dashboard_meeting_participants**](docs/DashboardsApi.md#dashboard_meeting_participants) | **GET** /metrics/meetings/{meetingId}/participants | List Meeting Participants
*ZoomUs::DashboardsApi* | [**dashboard_meeting_participants_qos**](docs/DashboardsApi.md#dashboard_meeting_participants_qos) | **GET** /metrics/meetings/{meetingId}/participants/qos | List Meeting Participants QOS
*ZoomUs::DashboardsApi* | [**dashboard_meetings**](docs/DashboardsApi.md#dashboard_meetings) | **GET** /metrics/meetings | List Meetings
*ZoomUs::DashboardsApi* | [**dashboard_webinar_detail**](docs/DashboardsApi.md#dashboard_webinar_detail) | **GET** /metrics/webinars/{webinarId} | Get Webinar Details
*ZoomUs::DashboardsApi* | [**dashboard_webinar_participant_qos**](docs/DashboardsApi.md#dashboard_webinar_participant_qos) | **GET** /metrics/webinars/{webinarId}/participants/{participantId}/qos | Get Webinar Participant QOS
*ZoomUs::DashboardsApi* | [**dashboard_webinar_participant_share**](docs/DashboardsApi.md#dashboard_webinar_participant_share) | **GET** /metrics/webinars/{webinarId}/participants/sharing | Get Sharing/Recording Details of Webinar Participants
*ZoomUs::DashboardsApi* | [**dashboard_webinar_participants**](docs/DashboardsApi.md#dashboard_webinar_participants) | **GET** /metrics/webinars/{webinarId}/participants | Get Webinar Participants
*ZoomUs::DashboardsApi* | [**dashboard_webinar_participants_qos**](docs/DashboardsApi.md#dashboard_webinar_participants_qos) | **GET** /metrics/webinars/{webinarId}/participants/qos | List Webinar Participant QOS
*ZoomUs::DashboardsApi* | [**dashboard_webinars**](docs/DashboardsApi.md#dashboard_webinars) | **GET** /metrics/webinars | List Webinars
*ZoomUs::DashboardsApi* | [**dashboard_zoom_room**](docs/DashboardsApi.md#dashboard_zoom_room) | **GET** /metrics/zoomrooms/{zoomroomId} | Get Zoom Rooms Details
*ZoomUs::DashboardsApi* | [**dashboard_zoom_room_issue**](docs/DashboardsApi.md#dashboard_zoom_room_issue) | **GET** /metrics/zoomrooms/issues | Get Top 25 issues of Zoom Rooms
*ZoomUs::DashboardsApi* | [**dashboard_zoom_rooms**](docs/DashboardsApi.md#dashboard_zoom_rooms) | **GET** /metrics/zoomrooms | List Zoom Rooms
*ZoomUs::DashboardsApi* | [**list_meeting_satisfaction**](docs/DashboardsApi.md#list_meeting_satisfaction) | **GET** /metrics/client/satisfaction | List Client Meeting Satisfaction
*ZoomUs::DevicesApi* | [**device_create**](docs/DevicesApi.md#device_create) | **POST** /h323/devices | Create a H.323/SIP Device
*ZoomUs::DevicesApi* | [**device_delete**](docs/DevicesApi.md#device_delete) | **DELETE** /h323/devices/{deviceId} | Delete a H.323/SIP Device
*ZoomUs::DevicesApi* | [**device_list**](docs/DevicesApi.md#device_list) | **GET** /h323/devices | List H.323/SIP Devices
*ZoomUs::DevicesApi* | [**device_update**](docs/DevicesApi.md#device_update) | **PATCH** /h323/devices/{deviceId} | Update a H.323/SIP Device
*ZoomUs::GroupsApi* | [**get_group_lock_settings**](docs/GroupsApi.md#get_group_lock_settings) | **GET** /groups/{groupId}/lock_settings | Get Locked Settings
*ZoomUs::GroupsApi* | [**get_group_settings**](docs/GroupsApi.md#get_group_settings) | **GET** /groups/{groupId}/settings | Get a Group's Settings
*ZoomUs::GroupsApi* | [**group**](docs/GroupsApi.md#group) | **GET** /groups/{groupId} | Get a Group
*ZoomUs::GroupsApi* | [**group_create**](docs/GroupsApi.md#group_create) | **POST** /groups | Create a Group
*ZoomUs::GroupsApi* | [**group_delete**](docs/GroupsApi.md#group_delete) | **DELETE** /groups/{groupId} | Delete a Group
*ZoomUs::GroupsApi* | [**group_locked_settings**](docs/GroupsApi.md#group_locked_settings) | **PATCH** /groups/{groupId}/lock_settings | Update Locked Settings
*ZoomUs::GroupsApi* | [**group_members**](docs/GroupsApi.md#group_members) | **GET** /groups/{groupId}/members | List Group Members
*ZoomUs::GroupsApi* | [**group_members_create**](docs/GroupsApi.md#group_members_create) | **POST** /groups/{groupId}/members | Add Group Members
*ZoomUs::GroupsApi* | [**group_members_delete**](docs/GroupsApi.md#group_members_delete) | **DELETE** /groups/{groupId}/members/{memberId} | Delete a Group Member
*ZoomUs::GroupsApi* | [**group_update**](docs/GroupsApi.md#group_update) | **PATCH** /groups/{groupId} | Update a Group
*ZoomUs::GroupsApi* | [**groups**](docs/GroupsApi.md#groups) | **GET** /groups | List Groups
*ZoomUs::GroupsApi* | [**update_a_group_member**](docs/GroupsApi.md#update_a_group_member) | **PATCH** /groups/{groupId}/members/{memberId} | Update a Group Member
*ZoomUs::GroupsApi* | [**update_group_settings**](docs/GroupsApi.md#update_group_settings) | **PATCH** /groups/{groupId}/settings | Update a Group's Settings
*ZoomUs::IMChatApi* | [**im_chat_messages**](docs/IMChatApi.md#im_chat_messages) | **GET** /im/chat/sessions/{sessionId} | Retrieve IM Chat Messages
*ZoomUs::IMChatApi* | [**im_chat_sessions**](docs/IMChatApi.md#im_chat_sessions) | **GET** /im/chat/sessions | Get IM Chat Sessions
*ZoomUs::IMChatApi* | [**listimmessages**](docs/IMChatApi.md#listimmessages) | **GET** /im/users/{userId}/chat/messages | Get User’s IM Messages
*ZoomUs::IMChatApi* | [**sendimmessages**](docs/IMChatApi.md#sendimmessages) | **POST** /im/users/me/chat/messages | Send IM messages
*ZoomUs::IMGroupsApi* | [**im_group**](docs/IMGroupsApi.md#im_group) | **GET** /im/groups/{groupId} | Retrieve an IM Directory Group
*ZoomUs::IMGroupsApi* | [**im_group_create**](docs/IMGroupsApi.md#im_group_create) | **POST** /im/groups | Create an IM Directory Group
*ZoomUs::IMGroupsApi* | [**im_group_delete**](docs/IMGroupsApi.md#im_group_delete) | **DELETE** /im/groups/{groupId} | Delete an IM Directory Group
*ZoomUs::IMGroupsApi* | [**im_group_members**](docs/IMGroupsApi.md#im_group_members) | **GET** /im/groups/{groupId}/members | List IM Directory Group Members
*ZoomUs::IMGroupsApi* | [**im_group_members_create**](docs/IMGroupsApi.md#im_group_members_create) | **POST** /im/groups/{groupId}/members | Add IM Directory Group Members
*ZoomUs::IMGroupsApi* | [**im_group_members_delete**](docs/IMGroupsApi.md#im_group_members_delete) | **DELETE** /im/groups/{groupId}/members/{memberId} | Delete an IM Directory Group Member
*ZoomUs::IMGroupsApi* | [**im_group_update**](docs/IMGroupsApi.md#im_group_update) | **PATCH** /im/groups/{groupId} | Update an IM Directory Group
*ZoomUs::IMGroupsApi* | [**im_groups**](docs/IMGroupsApi.md#im_groups) | **GET** /im/groups | List IM Directory Groups
*ZoomUs::MeetingsApi* | [**list_past_meeting_files**](docs/MeetingsApi.md#list_past_meeting_files) | **GET** /past_meetings/{meetingId}/files | List Past Meeting Files
*ZoomUs::MeetingsApi* | [**list_past_meeting_polls**](docs/MeetingsApi.md#list_past_meeting_polls) | **GET** /past_meetings/{meetingId}/polls | List Past Meeting's Poll Results
*ZoomUs::MeetingsApi* | [**meeting**](docs/MeetingsApi.md#meeting) | **GET** /meetings/{meetingId} | Get a Meeting
*ZoomUs::MeetingsApi* | [**meeting_create**](docs/MeetingsApi.md#meeting_create) | **POST** /users/{userId}/meetings | Create a Meeting
*ZoomUs::MeetingsApi* | [**meeting_delete**](docs/MeetingsApi.md#meeting_delete) | **DELETE** /meetings/{meetingId} | Delete a Meeting
*ZoomUs::MeetingsApi* | [**meeting_invitation**](docs/MeetingsApi.md#meeting_invitation) | **GET** /meetings/{meetingId}/invitation | Get Meeting Invitation
*ZoomUs::MeetingsApi* | [**meeting_live_stream_status_update**](docs/MeetingsApi.md#meeting_live_stream_status_update) | **PATCH** /meetings/{meetingId}/livestream/status | Update Live Stream Status
*ZoomUs::MeetingsApi* | [**meeting_live_stream_update**](docs/MeetingsApi.md#meeting_live_stream_update) | **PATCH** /meetings/{meetingId}/livestream | Update Live Stream
*ZoomUs::MeetingsApi* | [**meeting_poll_create**](docs/MeetingsApi.md#meeting_poll_create) | **POST** /meetings/{meetingId}/polls | Create a Meeting Poll
*ZoomUs::MeetingsApi* | [**meeting_poll_delete**](docs/MeetingsApi.md#meeting_poll_delete) | **DELETE** /meetings/{meetingId}/polls/{pollId} | Delete a Meeting Poll
*ZoomUs::MeetingsApi* | [**meeting_poll_get**](docs/MeetingsApi.md#meeting_poll_get) | **GET** /meetings/{meetingId}/polls/{pollId} | Get a Meeting Poll
*ZoomUs::MeetingsApi* | [**meeting_poll_update**](docs/MeetingsApi.md#meeting_poll_update) | **PUT** /meetings/{meetingId}/polls/{pollId} | Update a Meeting Poll
*ZoomUs::MeetingsApi* | [**meeting_polls**](docs/MeetingsApi.md#meeting_polls) | **GET** /meetings/{meetingId}/polls | List Meeting Polls
*ZoomUs::MeetingsApi* | [**meeting_registrant_create**](docs/MeetingsApi.md#meeting_registrant_create) | **POST** /meetings/{meetingId}/registrants | Add Meeting Registrant
*ZoomUs::MeetingsApi* | [**meeting_registrant_question_update**](docs/MeetingsApi.md#meeting_registrant_question_update) | **PATCH** /meetings/{meetingId}/registrants/questions | Update Registration Questions
*ZoomUs::MeetingsApi* | [**meeting_registrant_status**](docs/MeetingsApi.md#meeting_registrant_status) | **PUT** /meetings/{meetingId}/registrants/status | Update Meeting Registrant Status
*ZoomUs::MeetingsApi* | [**meeting_registrants**](docs/MeetingsApi.md#meeting_registrants) | **GET** /meetings/{meetingId}/registrants | List Meeting Registrants
*ZoomUs::MeetingsApi* | [**meeting_registrants_questions_get**](docs/MeetingsApi.md#meeting_registrants_questions_get) | **GET** /meetings/{meetingId}/registrants/questions | List Registration Questions
*ZoomUs::MeetingsApi* | [**meeting_status**](docs/MeetingsApi.md#meeting_status) | **PUT** /meetings/{meetingId}/status | Update Meeting Status
*ZoomUs::MeetingsApi* | [**meeting_update**](docs/MeetingsApi.md#meeting_update) | **PATCH** /meetings/{meetingId} | Update a Meeting
*ZoomUs::MeetingsApi* | [**meetings**](docs/MeetingsApi.md#meetings) | **GET** /users/{userId}/meetings | List Meetings
*ZoomUs::MeetingsApi* | [**past_meeting_details**](docs/MeetingsApi.md#past_meeting_details) | **GET** /past_meetings/{meetingUUID} | Get Past Meeting Details
*ZoomUs::MeetingsApi* | [**past_meeting_participants**](docs/MeetingsApi.md#past_meeting_participants) | **GET** /past_meetings/{meetingUUID}/participants | Get Past Meeting Participants
*ZoomUs::MeetingsApi* | [**past_meetings**](docs/MeetingsApi.md#past_meetings) | **GET** /past_meetings/{meetingId}/instances | List Ended Meeting Instances
*ZoomUs::PACApi* | [**user_pa_cs**](docs/PACApi.md#user_pa_cs) | **GET** /users/{userId}/pac | List a User's PAC Accounts
*ZoomUs::PhoneApi* | [**account_call_logs**](docs/PhoneApi.md#account_call_logs) | **GET** /phone/call_logs | Get Account's Call Logs
*ZoomUs::PhoneApi* | [**assign_calling_plan**](docs/PhoneApi.md#assign_calling_plan) | **POST** /phone/users/{userId}/calling_plans | Assign Calling Plan to a User
*ZoomUs::PhoneApi* | [**assign_phone_number**](docs/PhoneApi.md#assign_phone_number) | **POST** /phone/users/{userId}/phone_numbers | Assign Phone Number to User
*ZoomUs::PhoneApi* | [**change_main_company_number**](docs/PhoneApi.md#change_main_company_number) | **PUT** /phone/company_number | Change Main Company Number
*ZoomUs::PhoneApi* | [**get_phone_number_details**](docs/PhoneApi.md#get_phone_number_details) | **GET** /phone/numbers/{numberId} | Get Phone Number Details
*ZoomUs::PhoneApi* | [**list_account_phone_numbers**](docs/PhoneApi.md#list_account_phone_numbers) | **GET** /phone/numbers | List Phone Numbers
*ZoomUs::PhoneApi* | [**list_calling_plans**](docs/PhoneApi.md#list_calling_plans) | **GET** /phone/calling_plans | List Calling Plans
*ZoomUs::PhoneApi* | [**list_phone_users**](docs/PhoneApi.md#list_phone_users) | **GET** /phone/users | List Phone Users
*ZoomUs::PhoneApi* | [**phone_user**](docs/PhoneApi.md#phone_user) | **GET** /phone/users/{userId} | Get User's Profile
*ZoomUs::PhoneApi* | [**phone_user_call_logs**](docs/PhoneApi.md#phone_user_call_logs) | **GET** /phone/users/{userId}/call_logs | Get User's Call Logs
*ZoomUs::PhoneApi* | [**phone_user_recordings**](docs/PhoneApi.md#phone_user_recordings) | **GET** /phone/users/{userId}/recordings | Get User's Recordings
*ZoomUs::PhoneApi* | [**phone_user_settings**](docs/PhoneApi.md#phone_user_settings) | **GET** /phone/users/{userId}/settings | Get User's Settings
*ZoomUs::PhoneApi* | [**phone_user_voice_mails**](docs/PhoneApi.md#phone_user_voice_mails) | **GET** /phone/users/{userId}/voice_mails | Get User's Voicemails
*ZoomUs::PhoneApi* | [**unassign_calling_plan**](docs/PhoneApi.md#unassign_calling_plan) | **DELETE** /phone/users/{userId}/calling_plans/{type} | Unassign User's Calling Plan
*ZoomUs::PhoneApi* | [**unassign_phone_number**](docs/PhoneApi.md#unassign_phone_number) | **DELETE** /phone/users/{userId}/phone_numbers/{phoneNumberId} | Unassign User's Phone Number
*ZoomUs::PhoneApi* | [**update_user_profile**](docs/PhoneApi.md#update_user_profile) | **PATCH** /phone/users/{userId} | Update User's Profile
*ZoomUs::PhoneAutoReceptionistsApi* | [**assign_phone_numbers_auto_receptionist**](docs/PhoneAutoReceptionistsApi.md#assign_phone_numbers_auto_receptionist) | **POST** /phone/auto_receptionists/{autoReceptionistId}/phone_numbers | Assign Phone Numbers
*ZoomUs::PhoneAutoReceptionistsApi* | [**unassign_a_phone_num_auto_receptionist**](docs/PhoneAutoReceptionistsApi.md#unassign_a_phone_num_auto_receptionist) | **DELETE** /phone/auto_receptionists/{autoReceptionistId}/phone_numbers/{phoneNumberId} | Unassign a Phone Number
*ZoomUs::PhoneAutoReceptionistsApi* | [**unassign_all_phone_nums_auto_receptionist**](docs/PhoneAutoReceptionistsApi.md#unassign_all_phone_nums_auto_receptionist) | **DELETE** /phone/auto_receptionists/{autoReceptionistId}/phone_numbers | Unassign all Phone Numbers
*ZoomUs::PhoneAutoReceptionistsApi* | [**update_auto_receptionist**](docs/PhoneAutoReceptionistsApi.md#update_auto_receptionist) | **PATCH** /phone/auto_receptionists/{autoReceptionistId} | Update Auto Receptionist Details
*ZoomUs::PhoneBlockedListApi* | [**add_anumber_to_blocked_list**](docs/PhoneBlockedListApi.md#add_anumber_to_blocked_list) | **POST** /phone/blocked_list | Create a Blocked List
*ZoomUs::PhoneBlockedListApi* | [**delete_a_blocked_list**](docs/PhoneBlockedListApi.md#delete_a_blocked_list) | **DELETE** /phone/blocked_list/{blockedListId} | Delete a Blocked List
*ZoomUs::PhoneBlockedListApi* | [**get_a_blocked_list**](docs/PhoneBlockedListApi.md#get_a_blocked_list) | **GET** /phone/blocked_list/{blockedListId} | Get Blocked List Details
*ZoomUs::PhoneBlockedListApi* | [**list_blocked_list**](docs/PhoneBlockedListApi.md#list_blocked_list) | **GET** /phone/blocked_list | List Blocked Lists
*ZoomUs::PhoneBlockedListApi* | [**update_blocked_list**](docs/PhoneBlockedListApi.md#update_blocked_list) | **PATCH** /phone/blocked_list/{blockedListId} | Update a Blocked List
*ZoomUs::PhoneCallQueuesApi* | [**add_members_to_call_queue**](docs/PhoneCallQueuesApi.md#add_members_to_call_queue) | **POST** /phone/call_queues/{callQueueId}/members | Add Members to a Call Queue
*ZoomUs::PhoneCallQueuesApi* | [**assign_phone_to_call_queue**](docs/PhoneCallQueuesApi.md#assign_phone_to_call_queue) | **POST** /phone/call_queues/{callQueueId}/phone_numbers | Assign Numbers to a Call Queue
*ZoomUs::PhoneCallQueuesApi* | [**change_call_queue_manager**](docs/PhoneCallQueuesApi.md#change_call_queue_manager) | **PUT** /phone/call_queues/{callQueueId}/manager | Change Call Queue Manager
*ZoomUs::PhoneCallQueuesApi* | [**create_call_queue**](docs/PhoneCallQueuesApi.md#create_call_queue) | **POST** /phone/call_queues | Create a Call Queue
*ZoomUs::PhoneCallQueuesApi* | [**delete_a_call_queue**](docs/PhoneCallQueuesApi.md#delete_a_call_queue) | **DELETE** /phone/call_queues/{callQueueId} | Delete a Call Queue
*ZoomUs::PhoneCallQueuesApi* | [**get_a_call_queue**](docs/PhoneCallQueuesApi.md#get_a_call_queue) | **GET** /phone/call_queues/{callQueueId} | Get Call Queue Details
*ZoomUs::PhoneCallQueuesApi* | [**list_call_queues**](docs/PhoneCallQueuesApi.md#list_call_queues) | **GET** /phone/call_queues | List Call Queues
*ZoomUs::PhoneCallQueuesApi* | [**un_assign_phone_num_call_queue**](docs/PhoneCallQueuesApi.md#un_assign_phone_num_call_queue) | **DELETE** /phone/call_queues/{callQueueId}/phone_numbers/{phoneNumberId} | Unassign a Phone Number
*ZoomUs::PhoneCallQueuesApi* | [**unassign_a_phone_num_call_queue**](docs/PhoneCallQueuesApi.md#unassign_a_phone_num_call_queue) | **DELETE** /phone/call_queues/{callQueueId}/phone_numbers | Unassign all Phone Numbers
*ZoomUs::PhoneCallQueuesApi* | [**unassign_all_members**](docs/PhoneCallQueuesApi.md#unassign_all_members) | **DELETE** /phone/call_queues/{callQueueId}/members | Unassign all Members
*ZoomUs::PhoneCallQueuesApi* | [**unassign_member_from_call_queue**](docs/PhoneCallQueuesApi.md#unassign_member_from_call_queue) | **DELETE** /phone/call_queues/{callQueueId}/members/{memberId} | Unassign a Member
*ZoomUs::PhoneCallQueuesApi* | [**update_call_queue**](docs/PhoneCallQueuesApi.md#update_call_queue) | **PATCH** /phone/call_queues/{callQueueId} | Update Call Queue Details
*ZoomUs::PhoneDevicesApi* | [**add_phone_device**](docs/PhoneDevicesApi.md#add_phone_device) | **POST** /phone/devices | Add a Device
*ZoomUs::PhoneDevicesApi* | [**delete_a_device**](docs/PhoneDevicesApi.md#delete_a_device) | **DELETE** /phone/devices/{deviceId} | Delete a Device
*ZoomUs::PhoneDevicesApi* | [**get_a_device**](docs/PhoneDevicesApi.md#get_a_device) | **GET** /phone/devices/{deviceId} | Get Device Details
*ZoomUs::PhoneDevicesApi* | [**list_phone_devices**](docs/PhoneDevicesApi.md#list_phone_devices) | **GET** /phone/devices | List Devices
*ZoomUs::PhoneDevicesApi* | [**update_a_device**](docs/PhoneDevicesApi.md#update_a_device) | **PATCH** /phone/devices/{deviceId} | Update a Device
*ZoomUs::PhoneSiteApi* | [**create_phone_site**](docs/PhoneSiteApi.md#create_phone_site) | **POST** /phone/sites | Create a Phone Site
*ZoomUs::PhoneSiteApi* | [**delete_phone_site**](docs/PhoneSiteApi.md#delete_phone_site) | **DELETE** /phone/sites/{siteId} | Delete a Phone Site
*ZoomUs::PhoneSiteApi* | [**get_a_site**](docs/PhoneSiteApi.md#get_a_site) | **GET** /phone/sites/{siteId} | Get Phone Site Details
*ZoomUs::PhoneSiteApi* | [**list_phone_sites**](docs/PhoneSiteApi.md#list_phone_sites) | **GET** /phone/sites | List Phone Sites
*ZoomUs::PhoneSiteApi* | [**update_site_details**](docs/PhoneSiteApi.md#update_site_details) | **PATCH** /phone/sites/{siteId} | Update Phone Site Details
*ZoomUs::ReportsApi* | [**get_billing_invoices_reports**](docs/ReportsApi.md#get_billing_invoices_reports) | **GET** /report/billing/invoices | Get Billing Invoice Reports
*ZoomUs::ReportsApi* | [**get_billing_report**](docs/ReportsApi.md#get_billing_report) | **GET** /report/billing | Get Billing Reports
*ZoomUs::ReportsApi* | [**report_cloud_recording**](docs/ReportsApi.md#report_cloud_recording) | **GET** /report/cloud_recording | Get Cloud Recording Usage Report
*ZoomUs::ReportsApi* | [**report_daily**](docs/ReportsApi.md#report_daily) | **GET** /report/daily | Get Daily Usage Report
*ZoomUs::ReportsApi* | [**report_meeting_details**](docs/ReportsApi.md#report_meeting_details) | **GET** /report/meetings/{meetingId} | Get Meeting Detail Reports
*ZoomUs::ReportsApi* | [**report_meeting_participants**](docs/ReportsApi.md#report_meeting_participants) | **GET** /report/meetings/{meetingId}/participants | Get Meeting Participant Reports
*ZoomUs::ReportsApi* | [**report_meeting_polls**](docs/ReportsApi.md#report_meeting_polls) | **GET** /report/meetings/{meetingId}/polls | Get Meeting Poll Reports
*ZoomUs::ReportsApi* | [**report_meetings**](docs/ReportsApi.md#report_meetings) | **GET** /report/users/{userId}/meetings | Get Meeting Reports
*ZoomUs::ReportsApi* | [**report_operation_logs**](docs/ReportsApi.md#report_operation_logs) | **GET** /report/operationlogs | Get Operation Logs Report
*ZoomUs::ReportsApi* | [**report_sign_in_sign_out_activities**](docs/ReportsApi.md#report_sign_in_sign_out_activities) | **GET** /report/activities | Get Sign In / Sign Out Activity Report
*ZoomUs::ReportsApi* | [**report_telephone**](docs/ReportsApi.md#report_telephone) | **GET** /report/telephone | Get Telephone Reports
*ZoomUs::ReportsApi* | [**report_users**](docs/ReportsApi.md#report_users) | **GET** /report/users | Get Active/Inactive Host Reports
*ZoomUs::ReportsApi* | [**report_webinar_details**](docs/ReportsApi.md#report_webinar_details) | **GET** /report/webinars/{webinarId} | Get Webinar Detail Reports
*ZoomUs::ReportsApi* | [**report_webinar_participants**](docs/ReportsApi.md#report_webinar_participants) | **GET** /report/webinars/{webinarId}/participants | Get Webinar Participant Reports
*ZoomUs::ReportsApi* | [**report_webinar_polls**](docs/ReportsApi.md#report_webinar_polls) | **GET** /report/webinars/{webinarId}/polls | Get Webinar Poll Reports
*ZoomUs::ReportsApi* | [**report_webinar_qa**](docs/ReportsApi.md#report_webinar_qa) | **GET** /report/webinars/{webinarId}/qa | Get Webinar Q&A Report
*ZoomUs::RolesApi* | [**add_role_members**](docs/RolesApi.md#add_role_members) | **POST** /roles/{roleId}/members | Assign a Role to Members
*ZoomUs::RolesApi* | [**create_role**](docs/RolesApi.md#create_role) | **POST** /roles | Create a Role
*ZoomUs::RolesApi* | [**delete_role**](docs/RolesApi.md#delete_role) | **DELETE** /roles/{roleId} | Delete a Role
*ZoomUs::RolesApi* | [**get_role_information**](docs/RolesApi.md#get_role_information) | **GET** /roles/{roleId} | Get Role Information
*ZoomUs::RolesApi* | [**role_member_delete**](docs/RolesApi.md#role_member_delete) | **DELETE** /roles/{roleId}/members/{memberId} | Unassign a Member's Role
*ZoomUs::RolesApi* | [**role_members**](docs/RolesApi.md#role_members) | **GET** /roles/{roleId}/members | List Members in a Role
*ZoomUs::RolesApi* | [**roles**](docs/RolesApi.md#roles) | **GET** /roles | List Roles
*ZoomUs::RolesApi* | [**update_role**](docs/RolesApi.md#update_role) | **PATCH** /roles/{roleId} | Update Role Information
*ZoomUs::RoomsApi* | [**add_a_room**](docs/RoomsApi.md#add_a_room) | **POST** /rooms | Add a Zoom Room
*ZoomUs::RoomsApi* | [**change_zr_location**](docs/RoomsApi.md#change_zr_location) | **PUT** /rooms/{roomId}/location | Change a Zoom Room's Location
*ZoomUs::RoomsApi* | [**delete_a_zoom_room**](docs/RoomsApi.md#delete_a_zoom_room) | **DELETE** /rooms/{roomId} | Delete a Zoom Room
*ZoomUs::RoomsApi* | [**get_zr_profile**](docs/RoomsApi.md#get_zr_profile) | **GET** /rooms/{roomId} | Get Zoom Room Profile
*ZoomUs::RoomsApi* | [**get_zr_settings**](docs/RoomsApi.md#get_zr_settings) | **GET** /rooms/{roomId}/settings | Get Zoom Room Settings
*ZoomUs::RoomsApi* | [**list_zoom_rooms**](docs/RoomsApi.md#list_zoom_rooms) | **GET** /rooms | List Zoom Rooms
*ZoomUs::RoomsApi* | [**list_zr_devices**](docs/RoomsApi.md#list_zr_devices) | **GET** /rooms/{roomId}/devices | List Zoom Room Devices
*ZoomUs::RoomsApi* | [**update_room_profile**](docs/RoomsApi.md#update_room_profile) | **PATCH** /rooms/{roomId} | Update a Zoom Room Profile
*ZoomUs::RoomsApi* | [**update_zr_settings**](docs/RoomsApi.md#update_zr_settings) | **PATCH** /rooms/{roomId}/settings | Update Zoom Room Settings
*ZoomUs::RoomsAccountApi* | [**get_zr_account_profile**](docs/RoomsAccountApi.md#get_zr_account_profile) | **GET** /rooms/account_profile | Get Zoom Room Account Profile
*ZoomUs::RoomsAccountApi* | [**get_zr_account_settings**](docs/RoomsAccountApi.md#get_zr_account_settings) | **GET** /rooms/account_settings | Get Zoom Room Account Settings
*ZoomUs::RoomsAccountApi* | [**update_zoom_room_acc_settings**](docs/RoomsAccountApi.md#update_zoom_room_acc_settings) | **PATCH** /rooms/account_settings | Update Zoom Room Account Settings
*ZoomUs::RoomsAccountApi* | [**update_zr_acc_profile**](docs/RoomsAccountApi.md#update_zr_acc_profile) | **PATCH** /rooms/account_profile | Update Zoom Room Account Profile
*ZoomUs::RoomsLocationApi* | [**add_azr_location**](docs/RoomsLocationApi.md#add_azr_location) | **POST** /rooms/locations | Add a Location
*ZoomUs::RoomsLocationApi* | [**change_parent_location**](docs/RoomsLocationApi.md#change_parent_location) | **PUT** /rooms/locations/{locationId}/location | Change the Assigned Parent Location
*ZoomUs::RoomsLocationApi* | [**get_zr_location_profile**](docs/RoomsLocationApi.md#get_zr_location_profile) | **GET** /rooms/locations/{locationId} | Get Zoom Room Location Profile
*ZoomUs::RoomsLocationApi* | [**get_zr_location_settings**](docs/RoomsLocationApi.md#get_zr_location_settings) | **GET** /rooms/locations/{locationId}/settings | Get Location Settings
*ZoomUs::RoomsLocationApi* | [**get_zr_location_structure**](docs/RoomsLocationApi.md#get_zr_location_structure) | **GET** /rooms/locations/structure | Get Zoom Room Location Structure
*ZoomUs::RoomsLocationApi* | [**list_zr_locations**](docs/RoomsLocationApi.md#list_zr_locations) | **GET** /rooms/locations | List Zoom Room Locations
*ZoomUs::RoomsLocationApi* | [**update_zoom_rooms_location_structure**](docs/RoomsLocationApi.md#update_zoom_rooms_location_structure) | **PATCH** /rooms/locations/structure | Update Zoom Rooms Location Structure
*ZoomUs::RoomsLocationApi* | [**update_zr_location_profile**](docs/RoomsLocationApi.md#update_zr_location_profile) | **PATCH** /rooms/locations/{locationId} | Update Zoom Room Location Profile
*ZoomUs::RoomsLocationApi* | [**update_zr_location_settings**](docs/RoomsLocationApi.md#update_zr_location_settings) | **PATCH** /rooms/locations/{locationId}/settings | Update Location Settings
*ZoomUs::SIPConnectedAudioApi* | [**assign_sip_config**](docs/SIPConnectedAudioApi.md#assign_sip_config) | **PATCH** /accounts/{accountId}/sip_trunk/settings | Assign SIP Trunk Configuration
*ZoomUs::SIPConnectedAudioApi* | [**assign_sip_trunk_numbers**](docs/SIPConnectedAudioApi.md#assign_sip_trunk_numbers) | **POST** /accounts/{accountId}/sip_trunk/numbers | Assign Numbers
*ZoomUs::SIPConnectedAudioApi* | [**delete_all_sip_numbers**](docs/SIPConnectedAudioApi.md#delete_all_sip_numbers) | **DELETE** /accounts/{accountId}/sip_trunk/numbers | Delete All Numbers
*ZoomUs::SIPConnectedAudioApi* | [**list_sip_trunk_numbers**](docs/SIPConnectedAudioApi.md#list_sip_trunk_numbers) | **GET** /sip_trunk/numbers | List SIP Trunk Numbers
*ZoomUs::SIPPhone* | [**create_sip_phone**](docs/SIPPhone.md#create_sip_phone) | **POST** /sip_phones | Create SIP Phone
*ZoomUs::SIPPhone* | [**delete_sip_phone**](docs/SIPPhone.md#delete_sip_phone) | **DELETE** /sip_phones/{phoneId} | Delete SIP Phone
*ZoomUs::SIPPhone* | [**list_sip_phones**](docs/SIPPhone.md#list_sip_phones) | **GET** /sip_phones | List SIP Phones
*ZoomUs::SIPPhone* | [**update_sip_phone**](docs/SIPPhone.md#update_sip_phone) | **PATCH** /sip_phones/{phoneId} | Update SIP Phone
*ZoomUs::TSPApi* | [**tsp**](docs/TSPApi.md#tsp) | **GET** /tsp | Get Account's TSP Information
*ZoomUs::TSPApi* | [**tsp_update**](docs/TSPApi.md#tsp_update) | **PATCH** /tsp | Update account's TSP information
*ZoomUs::TSPApi* | [**tsp_url_update**](docs/TSPApi.md#tsp_url_update) | **PATCH** /users/{userId}/tsp/settings | Set Global Dial-in URL for a TSP User
*ZoomUs::TSPApi* | [**user_ts_ps**](docs/TSPApi.md#user_ts_ps) | **GET** /users/{userId}/tsp | List User's TSP accounts
*ZoomUs::TSPApi* | [**user_tsp**](docs/TSPApi.md#user_tsp) | **GET** /users/{userId}/tsp/{tspId} | Get a User's TSP Account
*ZoomUs::TSPApi* | [**user_tsp_create**](docs/TSPApi.md#user_tsp_create) | **POST** /users/{userId}/tsp | Add a User's TSP Account
*ZoomUs::TSPApi* | [**user_tsp_delete**](docs/TSPApi.md#user_tsp_delete) | **DELETE** /users/{userId}/tsp/{tspId} | Delete a User's TSP Account
*ZoomUs::TSPApi* | [**user_tsp_update**](docs/TSPApi.md#user_tsp_update) | **PATCH** /users/{userId}/tsp/{tspId} | Update a TSP Account
*ZoomUs::TrackingFieldApi* | [**trackingfield_create**](docs/TrackingFieldApi.md#trackingfield_create) | **POST** /tracking_fields | Create a Tracking Field
*ZoomUs::TrackingFieldApi* | [**trackingfield_delete**](docs/TrackingFieldApi.md#trackingfield_delete) | **DELETE** /tracking_fields/{fieldId} | Delete a Tracking Field
*ZoomUs::TrackingFieldApi* | [**trackingfield_get**](docs/TrackingFieldApi.md#trackingfield_get) | **GET** /tracking_fields/{fieldId} | Get a Tracking Field
*ZoomUs::TrackingFieldApi* | [**trackingfield_list**](docs/TrackingFieldApi.md#trackingfield_list) | **GET** /tracking_fields | List Tracking Fields
*ZoomUs::TrackingFieldApi* | [**trackingfield_update**](docs/TrackingFieldApi.md#trackingfield_update) | **PATCH** /tracking_fields/{fieldId} | Update a Tracking Field
*ZoomUs::UsersApi* | [**switch_user_account**](docs/UsersApi.md#switch_user_account) | **PUT** /accounts/{accountId}/users/{userId}/account | Switch a User's Account
*ZoomUs::UsersApi* | [**user**](docs/UsersApi.md#user) | **GET** /users/{userId} | Get a User
*ZoomUs::UsersApi* | [**user_assistant_create**](docs/UsersApi.md#user_assistant_create) | **POST** /users/{userId}/assistants | Add Assistants
*ZoomUs::UsersApi* | [**user_assistant_delete**](docs/UsersApi.md#user_assistant_delete) | **DELETE** /users/{userId}/assistants/{assistantId} | Delete a User Assistant
*ZoomUs::UsersApi* | [**user_assistants**](docs/UsersApi.md#user_assistants) | **GET** /users/{userId}/assistants | List User Assistants
*ZoomUs::UsersApi* | [**user_assistants_delete**](docs/UsersApi.md#user_assistants_delete) | **DELETE** /users/{userId}/assistants | Delete User Assistants
*ZoomUs::UsersApi* | [**user_create**](docs/UsersApi.md#user_create) | **POST** /users | Create Users
*ZoomUs::UsersApi* | [**user_delete**](docs/UsersApi.md#user_delete) | **DELETE** /users/{userId} | Delete User
*ZoomUs::UsersApi* | [**user_email**](docs/UsersApi.md#user_email) | **GET** /users/email | Check a User Email
*ZoomUs::UsersApi* | [**user_email_update**](docs/UsersApi.md#user_email_update) | **PUT** /users/{userId}/email | Update a User's Email
*ZoomUs::UsersApi* | [**user_password**](docs/UsersApi.md#user_password) | **PUT** /users/{userId}/password | Update a User's Password
*ZoomUs::UsersApi* | [**user_permission**](docs/UsersApi.md#user_permission) | **GET** /users/{userId}/permissions | Get User Permissions
*ZoomUs::UsersApi* | [**user_picture**](docs/UsersApi.md#user_picture) | **POST** /users/{userId}/picture | Upload a User's Profile Picture
*ZoomUs::UsersApi* | [**user_scheduler_delete**](docs/UsersApi.md#user_scheduler_delete) | **DELETE** /users/{userId}/schedulers/{schedulerId} | Delete a Scheduler
*ZoomUs::UsersApi* | [**user_schedulers**](docs/UsersApi.md#user_schedulers) | **GET** /users/{userId}/schedulers | List User Schedulers
*ZoomUs::UsersApi* | [**user_schedulers_delete**](docs/UsersApi.md#user_schedulers_delete) | **DELETE** /users/{userId}/schedulers | Delete User Schedulers
*ZoomUs::UsersApi* | [**user_settings**](docs/UsersApi.md#user_settings) | **GET** /users/{userId}/settings | Get User Settings
*ZoomUs::UsersApi* | [**user_settings_update**](docs/UsersApi.md#user_settings_update) | **PATCH** /users/{userId}/settings | Update User Settings
*ZoomUs::UsersApi* | [**user_sso_token_delete**](docs/UsersApi.md#user_sso_token_delete) | **DELETE** /users/{userId}/token | Revoke a User's SSO Token
*ZoomUs::UsersApi* | [**user_status**](docs/UsersApi.md#user_status) | **PUT** /users/{userId}/status | Update User Status
*ZoomUs::UsersApi* | [**user_token**](docs/UsersApi.md#user_token) | **GET** /users/{userId}/token | Get a User Token
*ZoomUs::UsersApi* | [**user_update**](docs/UsersApi.md#user_update) | **PATCH** /users/{userId} | Update User
*ZoomUs::UsersApi* | [**user_vanity_name**](docs/UsersApi.md#user_vanity_name) | **GET** /users/vanity_name | Check a User's PM Room Name
*ZoomUs::UsersApi* | [**user_zpk**](docs/UsersApi.md#user_zpk) | **GET** /users/zpk | Verify a User's zpk (Deprecated)
*ZoomUs::UsersApi* | [**users**](docs/UsersApi.md#users) | **GET** /users | List Users
*ZoomUs::WebinarsApi* | [**get_tracking_sources**](docs/WebinarsApi.md#get_tracking_sources) | **GET** /webinars/{webinarId}/tracking_sources | Get Webinar Tracking Sources
*ZoomUs::WebinarsApi* | [**list_past_webinar_files**](docs/WebinarsApi.md#list_past_webinar_files) | **GET** /past_webinars/{webinarId}/files | List Past Webinar Files
*ZoomUs::WebinarsApi* | [**list_past_webinar_poll_results**](docs/WebinarsApi.md#list_past_webinar_poll_results) | **GET** /past_webinars/{webinarId}/polls | List Past Webinar Poll Results
*ZoomUs::WebinarsApi* | [**list_past_webinar_qa**](docs/WebinarsApi.md#list_past_webinar_qa) | **GET** /past_webinars/{webinarId}/qa | List Q&A of Past Webinar
*ZoomUs::WebinarsApi* | [**past_webinars**](docs/WebinarsApi.md#past_webinars) | **GET** /past_webinars/{webinarId}/instances | List Past Webinar Instances
*ZoomUs::WebinarsApi* | [**webinar**](docs/WebinarsApi.md#webinar) | **GET** /webinars/{webinarId} | Get a Webinar
*ZoomUs::WebinarsApi* | [**webinar_absentees**](docs/WebinarsApi.md#webinar_absentees) | **GET** /past_webinars/{WebinarUUID}/absentees | Get Webinar Absentees
*ZoomUs::WebinarsApi* | [**webinar_create**](docs/WebinarsApi.md#webinar_create) | **POST** /users/{userId}/webinars | Create a Webinar
*ZoomUs::WebinarsApi* | [**webinar_delete**](docs/WebinarsApi.md#webinar_delete) | **DELETE** /webinars/{webinarId} | Delete a Webinar
*ZoomUs::WebinarsApi* | [**webinar_panelist_create**](docs/WebinarsApi.md#webinar_panelist_create) | **POST** /webinars/{webinarId}/panelists | Add Panelists
*ZoomUs::WebinarsApi* | [**webinar_panelist_delete**](docs/WebinarsApi.md#webinar_panelist_delete) | **DELETE** /webinars/{webinarId}/panelists/{panelistId} | Remove a Panelist
*ZoomUs::WebinarsApi* | [**webinar_panelists**](docs/WebinarsApi.md#webinar_panelists) | **GET** /webinars/{webinarId}/panelists | List Panelists
*ZoomUs::WebinarsApi* | [**webinar_panelists_delete**](docs/WebinarsApi.md#webinar_panelists_delete) | **DELETE** /webinars/{webinarId}/panelists | Remove Panelists
*ZoomUs::WebinarsApi* | [**webinar_poll_create**](docs/WebinarsApi.md#webinar_poll_create) | **POST** /webinars/{webinarId}/polls | Create a Webinar's Poll
*ZoomUs::WebinarsApi* | [**webinar_poll_delete**](docs/WebinarsApi.md#webinar_poll_delete) | **DELETE** /webinars/{webinarId}/polls/{pollId} | Delete a Webinar Poll
*ZoomUs::WebinarsApi* | [**webinar_poll_get**](docs/WebinarsApi.md#webinar_poll_get) | **GET** /webinars/{webinarId}/polls/{pollId} | Get a Webinar Poll
*ZoomUs::WebinarsApi* | [**webinar_poll_update**](docs/WebinarsApi.md#webinar_poll_update) | **PUT** /webinars/{webinarId}/polls/{pollId} | Update a Webinar Poll
*ZoomUs::WebinarsApi* | [**webinar_polls**](docs/WebinarsApi.md#webinar_polls) | **GET** /webinars/{webinarId}/polls | List a Webinar's Polls
*ZoomUs::WebinarsApi* | [**webinar_registrant_create**](docs/WebinarsApi.md#webinar_registrant_create) | **POST** /webinars/{webinarId}/registrants | Add a Webinar Registrant
*ZoomUs::WebinarsApi* | [**webinar_registrant_get**](docs/WebinarsApi.md#webinar_registrant_get) | **GET** /webinars/{webinarId}/registrants/{registrantId} | Get a Webinar Registrant
*ZoomUs::WebinarsApi* | [**webinar_registrant_question_update**](docs/WebinarsApi.md#webinar_registrant_question_update) | **PATCH** /webinars/{webinarId}/registrants/questions | Update Registration Questions
*ZoomUs::WebinarsApi* | [**webinar_registrant_status**](docs/WebinarsApi.md#webinar_registrant_status) | **PUT** /webinars/{webinarId}/registrants/status | Update Webinar Registrant Status
*ZoomUs::WebinarsApi* | [**webinar_registrants**](docs/WebinarsApi.md#webinar_registrants) | **GET** /webinars/{webinarId}/registrants | List Webinar Registrants
*ZoomUs::WebinarsApi* | [**webinar_registrants_questions_get**](docs/WebinarsApi.md#webinar_registrants_questions_get) | **GET** /webinars/{webinarId}/registrants/questions | List Registration Questions
*ZoomUs::WebinarsApi* | [**webinar_status**](docs/WebinarsApi.md#webinar_status) | **PUT** /webinars/{webinarId}/status | Update Webinar Status
*ZoomUs::WebinarsApi* | [**webinar_update**](docs/WebinarsApi.md#webinar_update) | **PATCH** /webinars/{webinarId} | Update a Webinar
*ZoomUs::WebinarsApi* | [**webinars**](docs/WebinarsApi.md#webinars) | **GET** /users/{userId}/webinars | List Webinars


## Documentation for Models

 - [ZoomUs::Account](docs/Account.md)
 - [ZoomUs::AccountList](docs/AccountList.md)
 - [ZoomUs::AccountListAccounts](docs/AccountListAccounts.md)
 - [ZoomUs::AccountListItem](docs/AccountListItem.md)
 - [ZoomUs::AccountOptions](docs/AccountOptions.md)
 - [ZoomUs::AccountPlan](docs/AccountPlan.md)
 - [ZoomUs::AccountPlanBaseRequired](docs/AccountPlanBaseRequired.md)
 - [ZoomUs::AccountPlanRequired](docs/AccountPlanRequired.md)
 - [ZoomUs::AccountPlans](docs/AccountPlans.md)
 - [ZoomUs::AccountSettings](docs/AccountSettings.md)
 - [ZoomUs::AccountSettingsAuthentication](docs/AccountSettingsAuthentication.md)
 - [ZoomUs::AccountSettingsAuthenticationUpdate](docs/AccountSettingsAuthenticationUpdate.md)
 - [ZoomUs::AccountSettingsEmailNotification](docs/AccountSettingsEmailNotification.md)
 - [ZoomUs::AccountSettingsFeature](docs/AccountSettingsFeature.md)
 - [ZoomUs::AccountSettingsInMeeting](docs/AccountSettingsInMeeting.md)
 - [ZoomUs::AccountSettingsIntegration](docs/AccountSettingsIntegration.md)
 - [ZoomUs::AccountSettingsRecording](docs/AccountSettingsRecording.md)
 - [ZoomUs::AccountSettingsRecordingAuthenticationUpdate](docs/AccountSettingsRecordingAuthenticationUpdate.md)
 - [ZoomUs::AccountSettingsRecordingAuthenticationUpdateAuthenticationOption](docs/AccountSettingsRecordingAuthenticationUpdateAuthenticationOption.md)
 - [ZoomUs::AccountSettingsScheduleMeeting](docs/AccountSettingsScheduleMeeting.md)
 - [ZoomUs::AccountSettingsScheduleMeting](docs/AccountSettingsScheduleMeting.md)
 - [ZoomUs::AccountSettingsSecurity](docs/AccountSettingsSecurity.md)
 - [ZoomUs::AccountSettingsTSP](docs/AccountSettingsTSP.md)
 - [ZoomUs::AccountSettingsTelephony](docs/AccountSettingsTelephony.md)
 - [ZoomUs::AccountSettingsTsp](docs/AccountSettingsTsp.md)
 - [ZoomUs::AccountSettingsZoomRooms](docs/AccountSettingsZoomRooms.md)
 - [ZoomUs::AccountsOptions](docs/AccountsOptions.md)
 - [ZoomUs::AccountsaccountIdlockSettingsInMeeting](docs/AccountsaccountIdlockSettingsInMeeting.md)
 - [ZoomUs::AccountsaccountIdlockSettingsScheduleMeeting](docs/AccountsaccountIdlockSettingsScheduleMeeting.md)
 - [ZoomUs::BillingContact](docs/BillingContact.md)
 - [ZoomUs::BillingContactRequired](docs/BillingContactRequired.md)
 - [ZoomUs::Body](docs/Body.md)
 - [ZoomUs::Body1](docs/Body1.md)
 - [ZoomUs::Body10](docs/Body10.md)
 - [ZoomUs::Body11](docs/Body11.md)
 - [ZoomUs::Body12](docs/Body12.md)
 - [ZoomUs::Body13](docs/Body13.md)
 - [ZoomUs::Body14](docs/Body14.md)
 - [ZoomUs::Body15](docs/Body15.md)
 - [ZoomUs::Body16](docs/Body16.md)
 - [ZoomUs::Body17](docs/Body17.md)
 - [ZoomUs::Body18](docs/Body18.md)
 - [ZoomUs::Body19](docs/Body19.md)
 - [ZoomUs::Body2](docs/Body2.md)
 - [ZoomUs::Body20](docs/Body20.md)
 - [ZoomUs::Body21](docs/Body21.md)
 - [ZoomUs::Body22](docs/Body22.md)
 - [ZoomUs::Body23](docs/Body23.md)
 - [ZoomUs::Body24](docs/Body24.md)
 - [ZoomUs::Body25](docs/Body25.md)
 - [ZoomUs::Body26](docs/Body26.md)
 - [ZoomUs::Body27](docs/Body27.md)
 - [ZoomUs::Body28](docs/Body28.md)
 - [ZoomUs::Body29](docs/Body29.md)
 - [ZoomUs::Body3](docs/Body3.md)
 - [ZoomUs::Body30](docs/Body30.md)
 - [ZoomUs::Body31](docs/Body31.md)
 - [ZoomUs::Body32](docs/Body32.md)
 - [ZoomUs::Body33](docs/Body33.md)
 - [ZoomUs::Body34](docs/Body34.md)
 - [ZoomUs::Body35](docs/Body35.md)
 - [ZoomUs::Body36](docs/Body36.md)
 - [ZoomUs::Body37](docs/Body37.md)
 - [ZoomUs::Body38](docs/Body38.md)
 - [ZoomUs::Body39](docs/Body39.md)
 - [ZoomUs::Body4](docs/Body4.md)
 - [ZoomUs::Body40](docs/Body40.md)
 - [ZoomUs::Body41](docs/Body41.md)
 - [ZoomUs::Body42](docs/Body42.md)
 - [ZoomUs::Body43](docs/Body43.md)
 - [ZoomUs::Body44](docs/Body44.md)
 - [ZoomUs::Body45](docs/Body45.md)
 - [ZoomUs::Body46](docs/Body46.md)
 - [ZoomUs::Body47](docs/Body47.md)
 - [ZoomUs::Body48](docs/Body48.md)
 - [ZoomUs::Body49](docs/Body49.md)
 - [ZoomUs::Body5](docs/Body5.md)
 - [ZoomUs::Body50](docs/Body50.md)
 - [ZoomUs::Body51](docs/Body51.md)
 - [ZoomUs::Body52](docs/Body52.md)
 - [ZoomUs::Body53](docs/Body53.md)
 - [ZoomUs::Body54](docs/Body54.md)
 - [ZoomUs::Body55](docs/Body55.md)
 - [ZoomUs::Body56](docs/Body56.md)
 - [ZoomUs::Body57](docs/Body57.md)
 - [ZoomUs::Body58](docs/Body58.md)
 - [ZoomUs::Body59](docs/Body59.md)
 - [ZoomUs::Body6](docs/Body6.md)
 - [ZoomUs::Body60](docs/Body60.md)
 - [ZoomUs::Body61](docs/Body61.md)
 - [ZoomUs::Body62](docs/Body62.md)
 - [ZoomUs::Body63](docs/Body63.md)
 - [ZoomUs::Body64](docs/Body64.md)
 - [ZoomUs::Body65](docs/Body65.md)
 - [ZoomUs::Body66](docs/Body66.md)
 - [ZoomUs::Body67](docs/Body67.md)
 - [ZoomUs::Body68](docs/Body68.md)
 - [ZoomUs::Body69](docs/Body69.md)
 - [ZoomUs::Body7](docs/Body7.md)
 - [ZoomUs::Body70](docs/Body70.md)
 - [ZoomUs::Body71](docs/Body71.md)
 - [ZoomUs::Body72](docs/Body72.md)
 - [ZoomUs::Body73](docs/Body73.md)
 - [ZoomUs::Body74](docs/Body74.md)
 - [ZoomUs::Body75](docs/Body75.md)
 - [ZoomUs::Body76](docs/Body76.md)
 - [ZoomUs::Body77](docs/Body77.md)
 - [ZoomUs::Body8](docs/Body8.md)
 - [ZoomUs::Body9](docs/Body9.md)
 - [ZoomUs::Channel](docs/Channel.md)
 - [ZoomUs::ChatchannelschannelIdmembersMembers](docs/ChatchannelschannelIdmembersMembers.md)
 - [ZoomUs::ChatusersmechannelsMembers](docs/ChatusersmechannelsMembers.md)
 - [ZoomUs::CreateWebinar](docs/CreateWebinar.md)
 - [ZoomUs::CreateWebinarSettings](docs/CreateWebinarSettings.md)
 - [ZoomUs::CustomQuestion](docs/CustomQuestion.md)
 - [ZoomUs::DateTime](docs/DateTime.md)
 - [ZoomUs::Device](docs/Device.md)
 - [ZoomUs::DeviceList](docs/DeviceList.md)
 - [ZoomUs::DomainsList](docs/DomainsList.md)
 - [ZoomUs::Group](docs/Group.md)
 - [ZoomUs::GroupList](docs/GroupList.md)
 - [ZoomUs::GroupMember](docs/GroupMember.md)
 - [ZoomUs::GroupMemberList](docs/GroupMemberList.md)
 - [ZoomUs::GroupMemberListMembers](docs/GroupMemberListMembers.md)
 - [ZoomUs::GroupUserSettingsAuthentication](docs/GroupUserSettingsAuthentication.md)
 - [ZoomUs::GroupUserSettingsAuthenticationUpdate](docs/GroupUserSettingsAuthenticationUpdate.md)
 - [ZoomUs::GroupsgroupIdlockSettingsRecording](docs/GroupsgroupIdlockSettingsRecording.md)
 - [ZoomUs::GroupsgroupIdmembersMembers](docs/GroupsgroupIdmembersMembers.md)
 - [ZoomUs::H323SIPDeviceList](docs/H323SIPDeviceList.md)
 - [ZoomUs::IMGroup](docs/IMGroup.md)
 - [ZoomUs::IMGroupList](docs/IMGroupList.md)
 - [ZoomUs::ImgroupsgroupIdmembersMembers](docs/ImgroupsgroupIdmembersMembers.md)
 - [ZoomUs::InlineResponse200](docs/InlineResponse200.md)
 - [ZoomUs::InlineResponse2001](docs/InlineResponse2001.md)
 - [ZoomUs::InlineResponse20010](docs/InlineResponse20010.md)
 - [ZoomUs::InlineResponse200100](docs/InlineResponse200100.md)
 - [ZoomUs::InlineResponse200100Invoices](docs/InlineResponse200100Invoices.md)
 - [ZoomUs::InlineResponse20011](docs/InlineResponse20011.md)
 - [ZoomUs::InlineResponse20011Members](docs/InlineResponse20011Members.md)
 - [ZoomUs::InlineResponse20012](docs/InlineResponse20012.md)
 - [ZoomUs::InlineResponse20013](docs/InlineResponse20013.md)
 - [ZoomUs::InlineResponse20014](docs/InlineResponse20014.md)
 - [ZoomUs::InlineResponse20015](docs/InlineResponse20015.md)
 - [ZoomUs::InlineResponse20015PlanAudio](docs/InlineResponse20015PlanAudio.md)
 - [ZoomUs::InlineResponse20015PlanBase](docs/InlineResponse20015PlanBase.md)
 - [ZoomUs::InlineResponse20015PlanZoomRooms](docs/InlineResponse20015PlanZoomRooms.md)
 - [ZoomUs::InlineResponse20016](docs/InlineResponse20016.md)
 - [ZoomUs::InlineResponse20017](docs/InlineResponse20017.md)
 - [ZoomUs::InlineResponse20018](docs/InlineResponse20018.md)
 - [ZoomUs::InlineResponse20018Members](docs/InlineResponse20018Members.md)
 - [ZoomUs::InlineResponse20019](docs/InlineResponse20019.md)
 - [ZoomUs::InlineResponse2001Phones](docs/InlineResponse2001Phones.md)
 - [ZoomUs::InlineResponse2002](docs/InlineResponse2002.md)
 - [ZoomUs::InlineResponse20020](docs/InlineResponse20020.md)
 - [ZoomUs::InlineResponse20020Sessions](docs/InlineResponse20020Sessions.md)
 - [ZoomUs::InlineResponse20021](docs/InlineResponse20021.md)
 - [ZoomUs::InlineResponse20021Messages](docs/InlineResponse20021Messages.md)
 - [ZoomUs::InlineResponse20022](docs/InlineResponse20022.md)
 - [ZoomUs::InlineResponse20023](docs/InlineResponse20023.md)
 - [ZoomUs::InlineResponse20024](docs/InlineResponse20024.md)
 - [ZoomUs::InlineResponse20024Participants](docs/InlineResponse20024Participants.md)
 - [ZoomUs::InlineResponse20025](docs/InlineResponse20025.md)
 - [ZoomUs::InlineResponse20025CustomQuestions](docs/InlineResponse20025CustomQuestions.md)
 - [ZoomUs::InlineResponse20025Questions](docs/InlineResponse20025Questions.md)
 - [ZoomUs::InlineResponse20026](docs/InlineResponse20026.md)
 - [ZoomUs::InlineResponse20027](docs/InlineResponse20027.md)
 - [ZoomUs::InlineResponse20027Participants](docs/InlineResponse20027Participants.md)
 - [ZoomUs::InlineResponse20028](docs/InlineResponse20028.md)
 - [ZoomUs::InlineResponse20028Details](docs/InlineResponse20028Details.md)
 - [ZoomUs::InlineResponse20028Participants](docs/InlineResponse20028Participants.md)
 - [ZoomUs::InlineResponse20029](docs/InlineResponse20029.md)
 - [ZoomUs::InlineResponse2002Rooms](docs/InlineResponse2002Rooms.md)
 - [ZoomUs::InlineResponse2003](docs/InlineResponse2003.md)
 - [ZoomUs::InlineResponse20030](docs/InlineResponse20030.md)
 - [ZoomUs::InlineResponse20030Participants](docs/InlineResponse20030Participants.md)
 - [ZoomUs::InlineResponse20031](docs/InlineResponse20031.md)
 - [ZoomUs::InlineResponse20031Users](docs/InlineResponse20031Users.md)
 - [ZoomUs::InlineResponse20032](docs/InlineResponse20032.md)
 - [ZoomUs::InlineResponse20032ClientFeedbacks](docs/InlineResponse20032ClientFeedbacks.md)
 - [ZoomUs::InlineResponse20033](docs/InlineResponse20033.md)
 - [ZoomUs::InlineResponse20033IssueDetails](docs/InlineResponse20033IssueDetails.md)
 - [ZoomUs::InlineResponse20034](docs/InlineResponse20034.md)
 - [ZoomUs::InlineResponse20034Users](docs/InlineResponse20034Users.md)
 - [ZoomUs::InlineResponse20035](docs/InlineResponse20035.md)
 - [ZoomUs::InlineResponse20035Meetings](docs/InlineResponse20035Meetings.md)
 - [ZoomUs::InlineResponse20036](docs/InlineResponse20036.md)
 - [ZoomUs::InlineResponse20036TrackingFields](docs/InlineResponse20036TrackingFields.md)
 - [ZoomUs::InlineResponse20037](docs/InlineResponse20037.md)
 - [ZoomUs::InlineResponse20037Participants](docs/InlineResponse20037Participants.md)
 - [ZoomUs::InlineResponse20038](docs/InlineResponse20038.md)
 - [ZoomUs::InlineResponse20038QuestionDetails](docs/InlineResponse20038QuestionDetails.md)
 - [ZoomUs::InlineResponse20038Questions](docs/InlineResponse20038Questions.md)
 - [ZoomUs::InlineResponse20039](docs/InlineResponse20039.md)
 - [ZoomUs::InlineResponse2003MainAutoReceptionist](docs/InlineResponse2003MainAutoReceptionist.md)
 - [ZoomUs::InlineResponse2003Sites](docs/InlineResponse2003Sites.md)
 - [ZoomUs::InlineResponse2004](docs/InlineResponse2004.md)
 - [ZoomUs::InlineResponse20040](docs/InlineResponse20040.md)
 - [ZoomUs::InlineResponse20040Participants](docs/InlineResponse20040Participants.md)
 - [ZoomUs::InlineResponse20041](docs/InlineResponse20041.md)
 - [ZoomUs::InlineResponse20041Questions](docs/InlineResponse20041Questions.md)
 - [ZoomUs::InlineResponse20042](docs/InlineResponse20042.md)
 - [ZoomUs::InlineResponse20042Questions](docs/InlineResponse20042Questions.md)
 - [ZoomUs::InlineResponse20043](docs/InlineResponse20043.md)
 - [ZoomUs::InlineResponse20043TelephonyUsage](docs/InlineResponse20043TelephonyUsage.md)
 - [ZoomUs::InlineResponse20044](docs/InlineResponse20044.md)
 - [ZoomUs::InlineResponse20044OperationLogs](docs/InlineResponse20044OperationLogs.md)
 - [ZoomUs::InlineResponse20045](docs/InlineResponse20045.md)
 - [ZoomUs::InlineResponse20045DialInNumbers](docs/InlineResponse20045DialInNumbers.md)
 - [ZoomUs::InlineResponse20046](docs/InlineResponse20046.md)
 - [ZoomUs::InlineResponse20046Users](docs/InlineResponse20046Users.md)
 - [ZoomUs::InlineResponse20047](docs/InlineResponse20047.md)
 - [ZoomUs::InlineResponse20048](docs/InlineResponse20048.md)
 - [ZoomUs::InlineResponse20049](docs/InlineResponse20049.md)
 - [ZoomUs::InlineResponse20049DedicatedDialInNumber](docs/InlineResponse20049DedicatedDialInNumber.md)
 - [ZoomUs::InlineResponse20049PacAccounts](docs/InlineResponse20049PacAccounts.md)
 - [ZoomUs::InlineResponse2004MainAutoReceptionist](docs/InlineResponse2004MainAutoReceptionist.md)
 - [ZoomUs::InlineResponse2005](docs/InlineResponse2005.md)
 - [ZoomUs::InlineResponse20050](docs/InlineResponse20050.md)
 - [ZoomUs::InlineResponse20050DialInNumbers](docs/InlineResponse20050DialInNumbers.md)
 - [ZoomUs::InlineResponse20051](docs/InlineResponse20051.md)
 - [ZoomUs::InlineResponse20052](docs/InlineResponse20052.md)
 - [ZoomUs::InlineResponse20053](docs/InlineResponse20053.md)
 - [ZoomUs::InlineResponse20054](docs/InlineResponse20054.md)
 - [ZoomUs::InlineResponse20055](docs/InlineResponse20055.md)
 - [ZoomUs::InlineResponse20056](docs/InlineResponse20056.md)
 - [ZoomUs::InlineResponse20056CustomQuestions](docs/InlineResponse20056CustomQuestions.md)
 - [ZoomUs::InlineResponse20056Questions](docs/InlineResponse20056Questions.md)
 - [ZoomUs::InlineResponse20057](docs/InlineResponse20057.md)
 - [ZoomUs::InlineResponse20058](docs/InlineResponse20058.md)
 - [ZoomUs::InlineResponse20059](docs/InlineResponse20059.md)
 - [ZoomUs::InlineResponse20059ClientFeedbackDetails](docs/InlineResponse20059ClientFeedbackDetails.md)
 - [ZoomUs::InlineResponse2005Contacts](docs/InlineResponse2005Contacts.md)
 - [ZoomUs::InlineResponse2006](docs/InlineResponse2006.md)
 - [ZoomUs::InlineResponse20060](docs/InlineResponse20060.md)
 - [ZoomUs::InlineResponse20060Messages](docs/InlineResponse20060Messages.md)
 - [ZoomUs::InlineResponse20061](docs/InlineResponse20061.md)
 - [ZoomUs::InlineResponse20061CallingPlan](docs/InlineResponse20061CallingPlan.md)
 - [ZoomUs::InlineResponse20061PhoneNumbers](docs/InlineResponse20061PhoneNumbers.md)
 - [ZoomUs::InlineResponse20062](docs/InlineResponse20062.md)
 - [ZoomUs::InlineResponse20062OutboundCaller](docs/InlineResponse20062OutboundCaller.md)
 - [ZoomUs::InlineResponse20063](docs/InlineResponse20063.md)
 - [ZoomUs::InlineResponse20063CallLogs](docs/InlineResponse20063CallLogs.md)
 - [ZoomUs::InlineResponse20064](docs/InlineResponse20064.md)
 - [ZoomUs::InlineResponse20064Recordings](docs/InlineResponse20064Recordings.md)
 - [ZoomUs::InlineResponse20065](docs/InlineResponse20065.md)
 - [ZoomUs::InlineResponse20065VoiceMails](docs/InlineResponse20065VoiceMails.md)
 - [ZoomUs::InlineResponse20066](docs/InlineResponse20066.md)
 - [ZoomUs::InlineResponse20067](docs/InlineResponse20067.md)
 - [ZoomUs::InlineResponse20067PhoneNumbers](docs/InlineResponse20067PhoneNumbers.md)
 - [ZoomUs::InlineResponse20068](docs/InlineResponse20068.md)
 - [ZoomUs::InlineResponse20068ActivityLogs](docs/InlineResponse20068ActivityLogs.md)
 - [ZoomUs::InlineResponse20069](docs/InlineResponse20069.md)
 - [ZoomUs::InlineResponse20069EmailNotification](docs/InlineResponse20069EmailNotification.md)
 - [ZoomUs::InlineResponse20069InMeeting](docs/InlineResponse20069InMeeting.md)
 - [ZoomUs::InlineResponse20069Recording](docs/InlineResponse20069Recording.md)
 - [ZoomUs::InlineResponse20069ScheduleMeeting](docs/InlineResponse20069ScheduleMeeting.md)
 - [ZoomUs::InlineResponse20069Telephony](docs/InlineResponse20069Telephony.md)
 - [ZoomUs::InlineResponse2006Messages](docs/InlineResponse2006Messages.md)
 - [ZoomUs::InlineResponse2007](docs/InlineResponse2007.md)
 - [ZoomUs::InlineResponse20070](docs/InlineResponse20070.md)
 - [ZoomUs::InlineResponse20070InMeeting](docs/InlineResponse20070InMeeting.md)
 - [ZoomUs::InlineResponse20070Recording](docs/InlineResponse20070Recording.md)
 - [ZoomUs::InlineResponse20070ScheduleMeeting](docs/InlineResponse20070ScheduleMeeting.md)
 - [ZoomUs::InlineResponse20070Tsp](docs/InlineResponse20070Tsp.md)
 - [ZoomUs::InlineResponse20071](docs/InlineResponse20071.md)
 - [ZoomUs::InlineResponse20072](docs/InlineResponse20072.md)
 - [ZoomUs::InlineResponse20072PlanBase](docs/InlineResponse20072PlanBase.md)
 - [ZoomUs::InlineResponse20072PlanLargeMeeting](docs/InlineResponse20072PlanLargeMeeting.md)
 - [ZoomUs::InlineResponse20072PlanRecording](docs/InlineResponse20072PlanRecording.md)
 - [ZoomUs::InlineResponse20072PlanWebinar](docs/InlineResponse20072PlanWebinar.md)
 - [ZoomUs::InlineResponse20072PlanZoomRooms](docs/InlineResponse20072PlanZoomRooms.md)
 - [ZoomUs::InlineResponse20073](docs/InlineResponse20073.md)
 - [ZoomUs::InlineResponse20073Meetings](docs/InlineResponse20073Meetings.md)
 - [ZoomUs::InlineResponse20073RecordingFiles](docs/InlineResponse20073RecordingFiles.md)
 - [ZoomUs::InlineResponse20074](docs/InlineResponse20074.md)
 - [ZoomUs::InlineResponse20074TrackingSources](docs/InlineResponse20074TrackingSources.md)
 - [ZoomUs::InlineResponse20075](docs/InlineResponse20075.md)
 - [ZoomUs::InlineResponse20075Basic](docs/InlineResponse20075Basic.md)
 - [ZoomUs::InlineResponse20076](docs/InlineResponse20076.md)
 - [ZoomUs::InlineResponse20076Locations](docs/InlineResponse20076Locations.md)
 - [ZoomUs::InlineResponse20077](docs/InlineResponse20077.md)
 - [ZoomUs::InlineResponse20078](docs/InlineResponse20078.md)
 - [ZoomUs::InlineResponse20078Basic](docs/InlineResponse20078Basic.md)
 - [ZoomUs::InlineResponse20079](docs/InlineResponse20079.md)
 - [ZoomUs::InlineResponse2007Channels](docs/InlineResponse2007Channels.md)
 - [ZoomUs::InlineResponse2008](docs/InlineResponse2008.md)
 - [ZoomUs::InlineResponse20080](docs/InlineResponse20080.md)
 - [ZoomUs::InlineResponse20080Basic](docs/InlineResponse20080Basic.md)
 - [ZoomUs::InlineResponse20081](docs/InlineResponse20081.md)
 - [ZoomUs::InlineResponse20081Devices](docs/InlineResponse20081Devices.md)
 - [ZoomUs::InlineResponse20082](docs/InlineResponse20082.md)
 - [ZoomUs::InlineResponse20082PhoneNumbers](docs/InlineResponse20082PhoneNumbers.md)
 - [ZoomUs::InlineResponse20083](docs/InlineResponse20083.md)
 - [ZoomUs::InlineResponse20083QuestionDetails](docs/InlineResponse20083QuestionDetails.md)
 - [ZoomUs::InlineResponse20083Questions](docs/InlineResponse20083Questions.md)
 - [ZoomUs::InlineResponse20084](docs/InlineResponse20084.md)
 - [ZoomUs::InlineResponse20084InMeetingFiles](docs/InlineResponse20084InMeetingFiles.md)
 - [ZoomUs::InlineResponse20085](docs/InlineResponse20085.md)
 - [ZoomUs::InlineResponse20086](docs/InlineResponse20086.md)
 - [ZoomUs::InlineResponse20086QuestionDetails](docs/InlineResponse20086QuestionDetails.md)
 - [ZoomUs::InlineResponse20086Questions](docs/InlineResponse20086Questions.md)
 - [ZoomUs::InlineResponse20087](docs/InlineResponse20087.md)
 - [ZoomUs::InlineResponse20087ClientSatisfaction](docs/InlineResponse20087ClientSatisfaction.md)
 - [ZoomUs::InlineResponse20088](docs/InlineResponse20088.md)
 - [ZoomUs::InlineResponse20088Assignee](docs/InlineResponse20088Assignee.md)
 - [ZoomUs::InlineResponse20088Devices](docs/InlineResponse20088Devices.md)
 - [ZoomUs::InlineResponse20088Site](docs/InlineResponse20088Site.md)
 - [ZoomUs::InlineResponse20089](docs/InlineResponse20089.md)
 - [ZoomUs::InlineResponse20089Assignee](docs/InlineResponse20089Assignee.md)
 - [ZoomUs::InlineResponse2008Contacts](docs/InlineResponse2008Contacts.md)
 - [ZoomUs::InlineResponse2009](docs/InlineResponse2009.md)
 - [ZoomUs::InlineResponse20090](docs/InlineResponse20090.md)
 - [ZoomUs::InlineResponse20090CallQueues](docs/InlineResponse20090CallQueues.md)
 - [ZoomUs::InlineResponse20090PhoneNumbers](docs/InlineResponse20090PhoneNumbers.md)
 - [ZoomUs::InlineResponse20090Site](docs/InlineResponse20090Site.md)
 - [ZoomUs::InlineResponse20091](docs/InlineResponse20091.md)
 - [ZoomUs::InlineResponse20091Members](docs/InlineResponse20091Members.md)
 - [ZoomUs::InlineResponse20091MembersCommonAreaPhones](docs/InlineResponse20091MembersCommonAreaPhones.md)
 - [ZoomUs::InlineResponse20091MembersUsers](docs/InlineResponse20091MembersUsers.md)
 - [ZoomUs::InlineResponse20091PhoneNumbers](docs/InlineResponse20091PhoneNumbers.md)
 - [ZoomUs::InlineResponse20091Site](docs/InlineResponse20091Site.md)
 - [ZoomUs::InlineResponse20092](docs/InlineResponse20092.md)
 - [ZoomUs::InlineResponse20092Assignee](docs/InlineResponse20092Assignee.md)
 - [ZoomUs::InlineResponse20093](docs/InlineResponse20093.md)
 - [ZoomUs::InlineResponse20093CallingPlans](docs/InlineResponse20093CallingPlans.md)
 - [ZoomUs::InlineResponse20094](docs/InlineResponse20094.md)
 - [ZoomUs::InlineResponse20094Site](docs/InlineResponse20094Site.md)
 - [ZoomUs::InlineResponse20094Users](docs/InlineResponse20094Users.md)
 - [ZoomUs::InlineResponse20095](docs/InlineResponse20095.md)
 - [ZoomUs::InlineResponse20095CallingPlans](docs/InlineResponse20095CallingPlans.md)
 - [ZoomUs::InlineResponse20095CommonAreaPhones](docs/InlineResponse20095CommonAreaPhones.md)
 - [ZoomUs::InlineResponse20095PhoneNumbers](docs/InlineResponse20095PhoneNumbers.md)
 - [ZoomUs::InlineResponse20095Site](docs/InlineResponse20095Site.md)
 - [ZoomUs::InlineResponse20096](docs/InlineResponse20096.md)
 - [ZoomUs::InlineResponse20097](docs/InlineResponse20097.md)
 - [ZoomUs::InlineResponse20097BlockedList](docs/InlineResponse20097BlockedList.md)
 - [ZoomUs::InlineResponse20098](docs/InlineResponse20098.md)
 - [ZoomUs::InlineResponse20099](docs/InlineResponse20099.md)
 - [ZoomUs::InlineResponse20099BillingReports](docs/InlineResponse20099BillingReports.md)
 - [ZoomUs::InlineResponse200Assignee](docs/InlineResponse200Assignee.md)
 - [ZoomUs::InlineResponse200PhoneNumbers](docs/InlineResponse200PhoneNumbers.md)
 - [ZoomUs::InlineResponse200Site](docs/InlineResponse200Site.md)
 - [ZoomUs::InlineResponse201](docs/InlineResponse201.md)
 - [ZoomUs::InlineResponse2011](docs/InlineResponse2011.md)
 - [ZoomUs::InlineResponse20110](docs/InlineResponse20110.md)
 - [ZoomUs::InlineResponse20110Occurrences](docs/InlineResponse20110Occurrences.md)
 - [ZoomUs::InlineResponse20110Settings](docs/InlineResponse20110Settings.md)
 - [ZoomUs::InlineResponse20110SettingsGlobalDialInNumbers](docs/InlineResponse20110SettingsGlobalDialInNumbers.md)
 - [ZoomUs::InlineResponse20111](docs/InlineResponse20111.md)
 - [ZoomUs::InlineResponse20112](docs/InlineResponse20112.md)
 - [ZoomUs::InlineResponse20112Questions](docs/InlineResponse20112Questions.md)
 - [ZoomUs::InlineResponse20113](docs/InlineResponse20113.md)
 - [ZoomUs::InlineResponse20114](docs/InlineResponse20114.md)
 - [ZoomUs::InlineResponse20115](docs/InlineResponse20115.md)
 - [ZoomUs::InlineResponse20116](docs/InlineResponse20116.md)
 - [ZoomUs::InlineResponse20117](docs/InlineResponse20117.md)
 - [ZoomUs::InlineResponse20118](docs/InlineResponse20118.md)
 - [ZoomUs::InlineResponse20118Settings](docs/InlineResponse20118Settings.md)
 - [ZoomUs::InlineResponse20119](docs/InlineResponse20119.md)
 - [ZoomUs::InlineResponse2012](docs/InlineResponse2012.md)
 - [ZoomUs::InlineResponse20120](docs/InlineResponse20120.md)
 - [ZoomUs::InlineResponse20121](docs/InlineResponse20121.md)
 - [ZoomUs::InlineResponse20122](docs/InlineResponse20122.md)
 - [ZoomUs::InlineResponse20123](docs/InlineResponse20123.md)
 - [ZoomUs::InlineResponse20124](docs/InlineResponse20124.md)
 - [ZoomUs::InlineResponse20125](docs/InlineResponse20125.md)
 - [ZoomUs::InlineResponse2013](docs/InlineResponse2013.md)
 - [ZoomUs::InlineResponse2014](docs/InlineResponse2014.md)
 - [ZoomUs::InlineResponse2015](docs/InlineResponse2015.md)
 - [ZoomUs::InlineResponse2016](docs/InlineResponse2016.md)
 - [ZoomUs::InlineResponse2017](docs/InlineResponse2017.md)
 - [ZoomUs::InlineResponse2018](docs/InlineResponse2018.md)
 - [ZoomUs::InlineResponse2019](docs/InlineResponse2019.md)
 - [ZoomUs::InlineResponse204](docs/InlineResponse204.md)
 - [ZoomUs::Meeting](docs/Meeting.md)
 - [ZoomUs::MeetingCreate](docs/MeetingCreate.md)
 - [ZoomUs::MeetingInfo](docs/MeetingInfo.md)
 - [ZoomUs::MeetingInfoGet](docs/MeetingInfoGet.md)
 - [ZoomUs::MeetingInstances](docs/MeetingInstances.md)
 - [ZoomUs::MeetingInvitation](docs/MeetingInvitation.md)
 - [ZoomUs::MeetingList](docs/MeetingList.md)
 - [ZoomUs::MeetingLiveStream](docs/MeetingLiveStream.md)
 - [ZoomUs::MeetingLiveStreamStatus](docs/MeetingLiveStreamStatus.md)
 - [ZoomUs::MeetingMetric](docs/MeetingMetric.md)
 - [ZoomUs::MeetingMetrics](docs/MeetingMetrics.md)
 - [ZoomUs::MeetingRecordingRegistrantList](docs/MeetingRecordingRegistrantList.md)
 - [ZoomUs::MeetingRegistrant](docs/MeetingRegistrant.md)
 - [ZoomUs::MeetingRegistrantList](docs/MeetingRegistrantList.md)
 - [ZoomUs::MeetingRegistrantQuestions](docs/MeetingRegistrantQuestions.md)
 - [ZoomUs::MeetingSettings](docs/MeetingSettings.md)
 - [ZoomUs::MeetingUpdate](docs/MeetingUpdate.md)
 - [ZoomUs::MeetingsmeetingIdlivestreamstatusSettings](docs/MeetingsmeetingIdlivestreamstatusSettings.md)
 - [ZoomUs::MeetingsmeetingIdrecordingsregistrantsstatusRegistrants](docs/MeetingsmeetingIdrecordingsregistrantsstatusRegistrants.md)
 - [ZoomUs::MeetingsmeetingIdregistrantsstatusRegistrants](docs/MeetingsmeetingIdregistrantsstatusRegistrants.md)
 - [ZoomUs::Occurrence](docs/Occurrence.md)
 - [ZoomUs::Occurrences](docs/Occurrences.md)
 - [ZoomUs::PAC](docs/PAC.md)
 - [ZoomUs::Pagination](docs/Pagination.md)
 - [ZoomUs::PaginationToken](docs/PaginationToken.md)
 - [ZoomUs::PaginationToken4IMChat](docs/PaginationToken4IMChat.md)
 - [ZoomUs::PaginationToken4Qos](docs/PaginationToken4Qos.md)
 - [ZoomUs::Panelist](docs/Panelist.md)
 - [ZoomUs::PanelistList](docs/PanelistList.md)
 - [ZoomUs::ParticipantQOS](docs/ParticipantQOS.md)
 - [ZoomUs::ParticipantQOSCpuUsage](docs/ParticipantQOSCpuUsage.md)
 - [ZoomUs::ParticipantQOSList](docs/ParticipantQOSList.md)
 - [ZoomUs::ParticipantQOSUserQos](docs/ParticipantQOSUserQos.md)
 - [ZoomUs::PhonePlan](docs/PhonePlan.md)
 - [ZoomUs::PhonePlan1](docs/PhonePlan1.md)
 - [ZoomUs::PhonePlan1PlanBase](docs/PhonePlan1PlanBase.md)
 - [ZoomUs::PhonePlan1PlanCalling](docs/PhonePlan1PlanCalling.md)
 - [ZoomUs::PhonePlan1PlanNumber](docs/PhonePlan1PlanNumber.md)
 - [ZoomUs::PhoneautoReceptionistsautoReceptionistIdphoneNumbersPhoneNumbers](docs/PhoneautoReceptionistsautoReceptionistIdphoneNumbersPhoneNumbers.md)
 - [ZoomUs::PhonecallQueuesMembers](docs/PhonecallQueuesMembers.md)
 - [ZoomUs::PhonecallQueuesMembersUsers](docs/PhonecallQueuesMembersUsers.md)
 - [ZoomUs::PhonecallQueuescallQueueIdmembersMembers](docs/PhonecallQueuescallQueueIdmembersMembers.md)
 - [ZoomUs::PhonecallQueuescallQueueIdmembersMembersUsers](docs/PhonecallQueuescallQueueIdmembersMembersUsers.md)
 - [ZoomUs::PhonecallQueuescallQueueIdphoneNumbersPhoneNumbers](docs/PhonecallQueuescallQueueIdphoneNumbersPhoneNumbers.md)
 - [ZoomUs::PhonesitesDefaultEmergencyAddress](docs/PhonesitesDefaultEmergencyAddress.md)
 - [ZoomUs::PhoneusersuserIdcallingPlansCallingPlans](docs/PhoneusersuserIdcallingPlansCallingPlans.md)
 - [ZoomUs::PhoneusersuserIdphoneNumbersPhoneNumbers](docs/PhoneusersuserIdphoneNumbersPhoneNumbers.md)
 - [ZoomUs::Poll](docs/Poll.md)
 - [ZoomUs::PollList](docs/PollList.md)
 - [ZoomUs::QOSAudio](docs/QOSAudio.md)
 - [ZoomUs::QOSObject](docs/QOSObject.md)
 - [ZoomUs::QOSParticipant](docs/QOSParticipant.md)
 - [ZoomUs::QOSParticipantList](docs/QOSParticipantList.md)
 - [ZoomUs::QOSVideo](docs/QOSVideo.md)
 - [ZoomUs::Recording](docs/Recording.md)
 - [ZoomUs::RecordingList](docs/RecordingList.md)
 - [ZoomUs::RecordingMeeting](docs/RecordingMeeting.md)
 - [ZoomUs::RecordingMeetingList](docs/RecordingMeetingList.md)
 - [ZoomUs::RecordingRegistrantList](docs/RecordingRegistrantList.md)
 - [ZoomUs::RecordingRegistrantQuestions](docs/RecordingRegistrantQuestions.md)
 - [ZoomUs::RecordingRegistrantQuestionsCustomQuestions](docs/RecordingRegistrantQuestionsCustomQuestions.md)
 - [ZoomUs::RecordingRegistrantQuestionsQuestions](docs/RecordingRegistrantQuestionsQuestions.md)
 - [ZoomUs::RecordingRegistrantStatus](docs/RecordingRegistrantStatus.md)
 - [ZoomUs::RecordingSettings](docs/RecordingSettings.md)
 - [ZoomUs::RecordingSettings1](docs/RecordingSettings1.md)
 - [ZoomUs::Recurrence](docs/Recurrence.md)
 - [ZoomUs::RecurrenceWebinar](docs/RecurrenceWebinar.md)
 - [ZoomUs::Registrant](docs/Registrant.md)
 - [ZoomUs::RegistrantList](docs/RegistrantList.md)
 - [ZoomUs::RegistrantStatus](docs/RegistrantStatus.md)
 - [ZoomUs::RegistrationList](docs/RegistrationList.md)
 - [ZoomUs::RegistrationList1](docs/RegistrationList1.md)
 - [ZoomUs::RoleList](docs/RoleList.md)
 - [ZoomUs::RoleMembersAdd](docs/RoleMembersAdd.md)
 - [ZoomUs::RoleMembersAddMembers](docs/RoleMembersAddMembers.md)
 - [ZoomUs::RoleMembersList](docs/RoleMembersList.md)
 - [ZoomUs::RolesroleIdmembersMembers](docs/RolesroleIdmembersMembers.md)
 - [ZoomUs::RoomslocationslocationIdBasic](docs/RoomslocationslocationIdBasic.md)
 - [ZoomUs::RoomsroomIdBasic](docs/RoomsroomIdBasic.md)
 - [ZoomUs::Session](docs/Session.md)
 - [ZoomUs::SessionUpdate](docs/SessionUpdate.md)
 - [ZoomUs::SessionWebinar](docs/SessionWebinar.md)
 - [ZoomUs::SessionWebinarUpdate](docs/SessionWebinarUpdate.md)
 - [ZoomUs::TSP](docs/TSP.md)
 - [ZoomUs::TSPAccount](docs/TSPAccount.md)
 - [ZoomUs::TSPAccount1](docs/TSPAccount1.md)
 - [ZoomUs::TSPAccountDialInNumbers](docs/TSPAccountDialInNumbers.md)
 - [ZoomUs::TSPAccountsList](docs/TSPAccountsList.md)
 - [ZoomUs::TSPAccountsList1](docs/TSPAccountsList1.md)
 - [ZoomUs::TSPAccountsList2](docs/TSPAccountsList2.md)
 - [ZoomUs::TSPGlobalDialInURLSetting](docs/TSPGlobalDialInURLSetting.md)
 - [ZoomUs::TheH323SIPDeviceObject1](docs/TheH323SIPDeviceObject1.md)
 - [ZoomUs::TheH323SIPDeviceObject_](docs/TheH323SIPDeviceObject_.md)
 - [ZoomUs::TrackingField](docs/TrackingField.md)
 - [ZoomUs::TrackingField1](docs/TrackingField1.md)
 - [ZoomUs::TrackingFieldList](docs/TrackingFieldList.md)
 - [ZoomUs::TspGlobalDialIn](docs/TspGlobalDialIn.md)
 - [ZoomUs::User](docs/User.md)
 - [ZoomUs::UserAssistantsList](docs/UserAssistantsList.md)
 - [ZoomUs::UserAssistantsList1](docs/UserAssistantsList1.md)
 - [ZoomUs::UserAssistantsListAssistants](docs/UserAssistantsListAssistants.md)
 - [ZoomUs::UserList](docs/UserList.md)
 - [ZoomUs::UserPermissions](docs/UserPermissions.md)
 - [ZoomUs::UserSchedulersList](docs/UserSchedulersList.md)
 - [ZoomUs::UserSchedulersListSchedulers](docs/UserSchedulersListSchedulers.md)
 - [ZoomUs::UserSettings](docs/UserSettings.md)
 - [ZoomUs::UserSettingsEmailNotification](docs/UserSettingsEmailNotification.md)
 - [ZoomUs::UserSettingsFeature](docs/UserSettingsFeature.md)
 - [ZoomUs::UserSettingsFeatureSettings](docs/UserSettingsFeatureSettings.md)
 - [ZoomUs::UserSettingsFeatureSettings1](docs/UserSettingsFeatureSettings1.md)
 - [ZoomUs::UserSettingsFeatureUpdate](docs/UserSettingsFeatureUpdate.md)
 - [ZoomUs::UserSettingsInMeeting](docs/UserSettingsInMeeting.md)
 - [ZoomUs::UserSettingsMeetingSettings](docs/UserSettingsMeetingSettings.md)
 - [ZoomUs::UserSettingsMeetingSettings1](docs/UserSettingsMeetingSettings1.md)
 - [ZoomUs::UserSettingsMeetingSettings2](docs/UserSettingsMeetingSettings2.md)
 - [ZoomUs::UserSettingsNotificationSettings](docs/UserSettingsNotificationSettings.md)
 - [ZoomUs::UserSettingsRecording](docs/UserSettingsRecording.md)
 - [ZoomUs::UserSettingsRecordingSettings](docs/UserSettingsRecordingSettings.md)
 - [ZoomUs::UserSettingsScheduleMeeting](docs/UserSettingsScheduleMeeting.md)
 - [ZoomUs::UserSettingsTSP](docs/UserSettingsTSP.md)
 - [ZoomUs::UserSettingsTSPSettings](docs/UserSettingsTSPSettings.md)
 - [ZoomUs::UserSettingsTelephony](docs/UserSettingsTelephony.md)
 - [ZoomUs::UserSettingsUpdate](docs/UserSettingsUpdate.md)
 - [ZoomUs::UserUpdate](docs/UserUpdate.md)
 - [ZoomUs::UsersUserInfo](docs/UsersUserInfo.md)
 - [ZoomUs::UsersuserIdmeetingsRecurrence](docs/UsersuserIdmeetingsRecurrence.md)
 - [ZoomUs::UsersuserIdmeetingsSettings](docs/UsersuserIdmeetingsSettings.md)
 - [ZoomUs::UsersuserIdmeetingsTrackingFields](docs/UsersuserIdmeetingsTrackingFields.md)
 - [ZoomUs::UsersuserIdtspDialInNumbers](docs/UsersuserIdtspDialInNumbers.md)
 - [ZoomUs::UsersuserIdtsptspIdDialInNumbers](docs/UsersuserIdtsptspIdDialInNumbers.md)
 - [ZoomUs::WebianrRegistrant](docs/WebianrRegistrant.md)
 - [ZoomUs::WebianrRegistrantCustomQuestions](docs/WebianrRegistrantCustomQuestions.md)
 - [ZoomUs::Webinar](docs/Webinar.md)
 - [ZoomUs::WebinarInfo](docs/WebinarInfo.md)
 - [ZoomUs::WebinarInstances](docs/WebinarInstances.md)
 - [ZoomUs::WebinarList](docs/WebinarList.md)
 - [ZoomUs::WebinarMetric](docs/WebinarMetric.md)
 - [ZoomUs::WebinarMetrics](docs/WebinarMetrics.md)
 - [ZoomUs::WebinarPanelist](docs/WebinarPanelist.md)
 - [ZoomUs::WebinarPanelistList](docs/WebinarPanelistList.md)
 - [ZoomUs::WebinarRegistrant](docs/WebinarRegistrant.md)
 - [ZoomUs::WebinarRegistrantList](docs/WebinarRegistrantList.md)
 - [ZoomUs::WebinarRegistrantQuestions](docs/WebinarRegistrantQuestions.md)
 - [ZoomUs::WebinarSettings](docs/WebinarSettings.md)
 - [ZoomUs::WebinarUpdate](docs/WebinarUpdate.md)
 - [ZoomUs::WebinarswebinarIdregistrantsstatusRegistrants](docs/WebinarswebinarIdregistrantsstatusRegistrants.md)
 - [ZoomUs::ZoomRoom](docs/ZoomRoom.md)
 - [ZoomUs::ZoomRoomList](docs/ZoomRoomList.md)


## Documentation for Authorization


### Bearer

- **Type**: API key
- **API key parameter name**: Authorization
- **Location**: HTTP header

### Client Credentials

- **Type**: OAuth
- **Flow**: application
- **Authorization URL**:
- **Scopes**: N/A

### OAuth

- **Type**: OAuth
- **Flow**: accessCode
- **Authorization URL**: https://zoom.us/oauth/authorize
- **Scopes**: N/A

